#define OPTIMIZE_ROM_CALLS
#include <tigcclib.h>
#include "extgraph.h"
#define GET_COLOR(card)	(GET_SUIT(card) & 1)
#define GET_SUIT(card)	(card/13)
#define GET_RANK(card)	(card%13)

enum MOVE_MODES			{TO_ACE, TO_CARD};
enum GAME_END_TYPE	{WIN, LOSS, NO_GAME};

// Save Data Structure
typedef struct
{
	unsigned short int in_progress:1, last_result:2;
	unsigned long int win, loss, streak_win, streak_loss, streak_current;
	long int score, best_score;
	short int dummy, columns[8][20], cells[4], aces[4], deck[52], selected[2], cursor[2], number[8], stagger, card_hold, empty;
}SAVE_GAME_TEMPLATE;
// Function prototypes
void delay(unsigned long x);
void delay_key(unsigned long x, short int row, short int col);
void wait(short int row, short int col);
void until_unpressed(short int row, short int col);
void shuffle(short int *deck);
int get_suit(short int card);
int get_rank(short int card);
void draw_card_background(int x, int y, int selected, char *buffer);
void draw_card_value(int x, int y, short int card, char *buffer);
int card_test(short int mode, short int card_under, short int card_moving);
void show_selected_card(short int card, char *buffer);
void draw_tableau(SAVE_GAME_TEMPLATE *game, char *buffer);
void deal_cards(SAVE_GAME_TEMPLATE *game);
int min_aces(short int *aces);
void game_end(short int end_type, SAVE_GAME_TEMPLATE *game);
void determine_empty(SAVE_GAME_TEMPLATE *game);
void show_stat(SAVE_GAME_TEMPLATE *game, char *buffer);
void no_good_move(char *buffer);

// Title Screen
unsigned char title_light89[]={0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x8F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x8F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x3F,0xFF,0xFC,0x00,0x00,0x18,0x00,0x01,0xFF,0x00,0x00,0x03,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFE,0x00,0x01,0x9C,0x00,0x00,0x7F,0xC0,0x00,0x33,0x80,0x00,0x73,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFF,0xC0,0xFF,0x5F,0x43,0xF4,0x3F,0xF4,0x3F,0xE3,0xF4,0x3F,0xD3,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFF,0xD1,0xFF,0x9F,0xC3,0xFA,0x1F,0xF8,0x3F,0xF3,0xFC,0x3F,0xE3,0xFF,0xFF,0xFF,0xFF,0xFC,0xFF,0xFF,0xFF,0xD1,0xFF,0xDF,0xA3,0xFD,0x0F,0xFA,0x3F,0xF3,0xF8,0x3F,0xF3,0xFF,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0xFF,0xF1,0xFF,0xDF,0xA3,0xFF,0x8F,0xFA,0x3F,0xFF,0xFA,0x3F,0xFF,0xFF,0x0F,0xFF,0xFF,0xFD,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0xA3,0xFF,0x8F,0xFA,0x3F,0xFF,0xFA,0x3F,0xFF,0xFF,0x00,0x00,0x1F,0xFB,0xFF,0xFF,0xFF,0xF1,0xFC,0xFF,0xA3,0xFF,0x8F,0xFA,0x3F,0x9F,0xFA,0x3F,0x9F,0xFF,0x00,0x00,0xC0,0x33,0xFF,0xFF,0xFF,0xF1,0xFC,0xFF,0xA3,0xFD,0x0F,0xFA,0x3F,0x9F,0xFA,0x3F,0x9F,0xFF,0x00,0x03,0xF0,0x27,0xFF,0xFF,0xFF,0xF0,0xF8,0xFF,0xA3,0xFD,0x1F,0xFA,0x3F,0x1F,0xFA,0x3F,0x1F,0xFF,0x00,0x0F,0xF0,0x23,0xFF,0xFF,0xFF,0xF0,0x00,0xFF,0xA3,0xF8,0x3F,0xFA,0x00,0x9F,0xFA,0x00,0x9F,0xFF,0x01,0xFC,0x00,0x47,0xFF,0xFF,0xFF,0xD0,0xF8,0xFF,0xA0,0x01,0xFF,0xFA,0x1E,0x1F,0xFA,0x1E,0x3F,0xFF,0x0F,0xE0,0x00,0x4F,0xFF,0xFF,0xFF,0xF1,0xFC,0xFF,0xA1,0x90,0xFF,0xFA,0x3F,0x9F,0xFA,0x3F,0x9F,0xFF,0x7F,0x03,0xF8,0xCF,0xFF,0xFF,0xFF,0xF1,0xFC,0xFF,0xA3,0xE8,0x7F,0xFA,0x3F,0x9F,0xFA,0x3F,0x9F,0xFF,0x00,0x30,0x38,0x8F,0xFF,0xFF,0xFF,0xF1,0xFE,0xFF,0xA3,0xF4,0x3F,0xFA,0x3F,0xDF,0xFA,0x3F,0xDF,0xFF,0x01,0x83,0xF0,0x8F,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0x83,0xF4,0x3F,0xFA,0x3F,0xFF,0xFA,0x3F,0xFF,0xFF,0x06,0x0F,0xF0,0x8F,0xFF,0xFF,0xFF,0xD1,0xFF,0xFF,0xA3,0xFA,0x1F,0xFA,0x3F,0xFF,0xFA,0x3F,0xFF,0xFF,0x00,0x3F,0xF0,0x8F,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0x83,0xFA,0x1F,0xFA,0x3F,0xFF,0xF8,0x3F,0xFF,0xFF,0x07,0xFD,0xF0,0xCF,0xFF,0xFF,0xFF,0xD1,0xFF,0xFF,0x83,0xFD,0x0F,0xFA,0x3F,0xF8,0xF8,0x3F,0xF9,0xFF,0x7F,0xFC,0xF0,0x47,0xFF,0xFF,0xFF,0xD0,0xFF,0xFF,0xC3,0xFE,0x87,0xFA,0x3F,0xF5,0xF8,0x3F,0xF5,0xFF,0x0F,0xE2,0xF8,0x47,0xFF,0xFF,0xFF,0xD0,0xFF,0xFF,0x41,0xFE,0xC3,0xF8,0x1F,0xC9,0xFC,0x3F,0xCB,0xFF,0x00,0x0F,0xE0,0x23,0xFF,0xFF,0xFE,0x00,0x0F,0xFC,0x00,0x3F,0xA0,0x40,0x00,0x07,0xC0,0x00,0x07,0xFF,0x00,0x00,0x20,0x11,0xFF,0xFF,0xFE,0x00,0x0F,0xF8,0x00,0x3F,0xC1,0xC0,0x00,0x0F,0x80,0x00,0x1F,0xFF,0x00,0x00,0x20,0x13,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x40,0x19,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x0C,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x04,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x06,0x7F,0xFF,0xFF,0xFE,0xFF,0xFF,0xF8,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x01,0x3F,0xFF,0xFF,0xF7,0xCF,0xFF,0xEF,0x0F,0x7F,0xFF,0x8C,0xFF,0xFF,0xFD,0x7F,0xFF,0x00,0x00,0x00,0x01,0x3F,0xFF,0xFF,0xCF,0xE7,0xFF,0xCF,0x9F,0x3F,0xFF,0x1C,0x7F,0xFF,0xFB,0x7F,0xFF,0x00,0x00,0x00,0x01,0xBF,0xFF,0xFF,0xCF,0xE7,0xFF,0xCF,0xFF,0xFF,0xFE,0x3E,0x1F,0xFF,0xE3,0xBF,0xFF,0x00,0x00,0x00,0x01,0xBF,0xFF,0xFF,0x8F,0xE3,0xFF,0xCF,0xFF,0x3F,0xFC,0x3F,0x1F,0xFF,0xE7,0x9F,0xFF,0x00,0x00,0x00,0x21,0xBF,0xFF,0xFF,0x9F,0xF9,0xFF,0xC7,0xFF,0x3F,0xFC,0xFF,0x87,0xFF,0xCF,0xEF,0xFF,0x00,0x00,0x08,0x61,0x3F,0xFF,0xFF,0xBF,0xFB,0xFF,0xC7,0xFE,0x7F,0xF8,0xFF,0xCF,0xFF,0xCF,0xEF,0xFF,0x00,0x00,0x08,0xE7,0x7F,0xFF,0xFF,0x7F,0xFD,0xFF,0xE3,0xFC,0x7F,0xF9,0xFF,0xE7,0xFF,0x9F,0xFF,0xFF,0x00,0x00,0x00,0x18,0xFF,0xFF,0xFF,0xFF,0xFB,0xFF,0xF1,0xF8,0xFF,0xFB,0xFF,0xE7,0xFF,0xCF,0xEF,0xFF,0x00,0x00,0x00,0x10,0xFF,0xFF,0xFF,0xBF,0xFB,0xFF,0xF8,0xF1,0xFF,0xFB,0xFF,0xE7,0xFF,0xC7,0xEF,0xFF,0x00,0x10,0x02,0x11,0xFF,0xFF,0xFF,0xD9,0xF7,0xFF,0xFC,0x63,0xFF,0xF9,0xFF,0xEF,0xFF,0xE7,0xCF,0xFF,0x00,0x20,0x1E,0x13,0xFF,0xFF,0xFF,0xF7,0x8F,0xFF,0xFF,0xDF,0xFF,0xFE,0x1C,0x1F,0xFF,0xF3,0x3F,0xFF,0x00,0x20,0xF8,0x13,0xFF,0xFF,0xFF,0xF7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x1E,0x2F,0xFF,0xF5,0x7F,0xFF,0x00,0x11,0xE0,0x33,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x7F,0xFF,0xFF,0xFF,0xFF,0x00,0x0F,0x80,0x73,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x03,0xE7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x1F,0x23,0xFF,0xFF,0xFF,0xFF,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x1E,0x23,0xFF,0xFF,0xFF,0xFC,0x00,0x3F,0xC0,0x00,0x01,0x80,0x01,0xFF,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0xC7,0xFF,0xFF,0xFF,0xE0,0xFF,0x80,0xF8,0x0F,0xE1,0xFA,0x0F,0xFF,0xF4,0x1F,0xFF,0xFF,0x00,0x00,0x00,0xC7,0xFF,0xFF,0xFF,0xC1,0xFF,0xC8,0xFD,0x1F,0xF9,0xFD,0x0F,0xFF,0xFA,0x1F,0xFF,0xFF,0x00,0x00,0x00,0x47,0xFF,0xFF,0xFF,0xD3,0xFF,0xEC,0xFD,0x0F,0xF9,0xFD,0x0F,0xFF,0xFA,0x3F,0xFF,0xFF,0x00,0x00,0x00,0x47,0xFF,0xFF,0xFF,0xA7,0xFF,0xF4,0xFD,0x0F,0xF9,0xFD,0x0F,0xFF,0xFA,0x1F,0xFF,0xFF,0x00,0x00,0x00,0x6F,0xFF,0xFF,0xFF,0x4F,0xFF,0xFC,0xFF,0x0F,0xFF,0xFF,0x0F,0xFF,0xFE,0x1F,0xFF,0xFF,0x00,0x00,0x00,0x6F,0xFF,0xFF,0xFE,0x8F,0xFF,0xFC,0x7F,0x0F,0xFF,0xFF,0x0F,0xFF,0xFE,0x1F,0xFF,0xFF,0x00,0x00,0x00,0x67,0xFF,0xFF,0xFE,0x8F,0xFF,0xFE,0x7F,0x0F,0xC7,0xFF,0x0F,0xFF,0xFA,0x1F,0xFF,0xFF,0xE0,0x00,0x00,0x47,0xFF,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x0F,0x8F,0xFF,0x0F,0xFF,0xFE,0x1B,0xFF,0xFF,0x70,0x00,0x00,0x47,0xFF,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x00,0x0F,0xFF,0x0F,0xFF,0xFE,0x1F,0xFF,0xFF,0xFC,0x00,0x00,0x87,0xFF,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x00,0x4F,0xFF,0x0F,0xFF,0xFE,0x1F,0xFF,0xFF,0xFF,0x00,0x00,0x83,0xFF,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x00,0x0F,0xFF,0x0F,0xFF,0xFE,0x1F,0xFF,0xFF,0xE0,0xFF,0xFF,0xE0,0xFF,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x1F,0xC6,0xFF,0x0F,0xFF,0x4E,0x01,0x3F,0xFF,0x00,0xFF,0xFF,0xF0,0x7F,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x0F,0xE7,0xFF,0x0F,0xF8,0x0E,0x00,0x07,0xFF,0x00,0xFF,0xFF,0xF8,0x3F,0xFF,0xFD,0x0F,0xFF,0xFF,0xFF,0x0F,0xE7,0xFF,0x0B,0xC0,0x0E,0x00,0x03,0xFF,0x0F,0xFE,0x1F,0xFB,0x03,0xFF,0xFE,0x87,0xFF,0xFF,0xFF,0x0F,0xFF,0xFF,0x04,0x00,0x0A,0x00,0x02,0x7F,0xFF,0xFE,0x3D,0xFB,0xC1,0xFF,0xFE,0x83,0xFF,0xFE,0x7D,0x0F,0xFF,0x7F,0x05,0x22,0x0E,0x00,0x10,0x3F,0xFF,0xFC,0x60,0xFB,0x01,0x7F,0xFE,0xC1,0xFF,0xFC,0x7F,0x0F,0xFE,0x6F,0x08,0x04,0x0E,0x00,0x00,0x1F,0xFF,0xFB,0x00,0xFB,0x04,0x3F,0xFF,0x41,0xFF,0xF8,0xFF,0x0F,0xFC,0x35,0x08,0x10,0x0E,0x00,0x00,0x0F,0xFF,0xFC,0x00,0xEE,0x0F,0x0B,0xFF,0xD0,0x3F,0xC3,0xFD,0x0F,0xE2,0x5D,0x00,0x02,0x0A,0x00,0x04,0x07,0xFF,0xF0,0x00,0xEC,0x1F,0x83,0xFF,0xE8,0x00,0x07,0xFA,0x07,0x04,0xE0,0x00,0x04,0x00,0x00,0x08,0x00,0xFF,0xF0,0x00,0xBC,0x1F,0xC1,0xFF,0xF6,0x00,0x1F,0xE0,0x00,0x11,0x80,0x00,0x10,0x00,0x00,0x02,0x00,0xFF,0xE0,0x00,0x18,0x3F,0xF8,0x3F,0xFF,0xC7,0xFF,0xFF,0xFF,0xFF,0xBF,0xFF,0xFE,0x3F,0xFF,0xFC,0x00,0xFF,0xE0,0x00,0x38,0x3F,0xFC,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFC,0x7F,0xFF,0xF8,0x00,0xFF,0xE0,0x00,0x30,0x7F,0xFE,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x7F,0xFF,0xF8,0x7F,0xFF,0xF0,0x00,0xFF,0x30,0x00,0x60,0x7F,0xFF,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xA8,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFE,0x00,0x40,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0xFF,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFC,0x00,0x81,0xFF,0xFF,0xF0,0x7F,0xFF,0xFF,0xFF,0xFF,0xAC,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF8,0x40,0x81,0xFF,0xFF,0xFC,0x3F,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0x77,0x03,0xFF,0xFF,0xFF,0x05,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF8,0x7F,0x07,0xFF,0xFF,0xFF,0x82,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFC,0x7E,0x07,0xFF,0xFF,0xFF,0xC0,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF9,0xEF,0xDE,0x0F,0xFF,0xFF,0xFF,0xE0,0x3F,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFD,0x6E,0x2E,0x1F,0xFF,0xFF,0xFF,0xF8,0x07,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0xFF,0xBC,0x1F,0xFF,0xFF,0xFF,0xFC,0x03,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x87,0xEC,0x3F,0xFF,0xFF,0xFF,0xFF,0x01,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0x07,0x98,0x7E,0x7F,0xFF,0xFF,0xFF,0xC0,0x1F,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0x07,0x30,0x7E,0x7F,0xFF,0xFF,0xFF,0xE0,0x0F,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x07,0xF0,0xFE,0x7C,0x7F,0xFF,0xFF,0xF0,0x07,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x07,0xE1,0xFC,0x78,0x3F,0xFF,0xFF,0xF8,0x00,0xDC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xE3,0xF8,0x78,0x3C,0x7F,0xFF,0xFE,0x00,0x33,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, 
title_dark89[]={0xEB,0xE1,0x00,0xC8,0xFE,0x3B,0x80,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xE0,0x00,0x01,0xFC,0x2C,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xE0,0x00,0x03,0xF8,0x5C,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xE0,0x00,0x07,0xF1,0xF8,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xE0,0x00,0x0F,0xE3,0x70,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xE0,0x00,0x1F,0xC7,0xC0,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xE0,0x00,0x1F,0x85,0x80,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xF0,0x00,0x3F,0x1B,0x80,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xC0,0x7E,0x3E,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0xFC,0x2C,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xFF,0xF8,0x58,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xFF,0xFF,0xF8,0xF8,0x03,0xFF,0xFF,0xFF,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0xFF,0xE1,0x70,0x07,0xFB,0xDA,0x6D,0x22,0xEA,0x9F,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0xE3,0xE0,0x0F,0xA6,0x73,0x46,0x59,0x25,0x41,0xAF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x02,0xC0,0x1F,0x59,0x96,0x98,0x42,0x02,0x13,0x53,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x05,0xC0,0x1F,0xE0,0x00,0x00,0x08,0x00,0x02,0x35,0x80,0x00,0x07,0x82,0x02,0x03,0xFF,0xFF,0xFF,0xFF,0x8F,0x80,0x1F,0x8D,0x00,0x02,0x1A,0x00,0x00,0x09,0xA0,0x00,0x43,0xE0,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFB,0x80,0x3F,0x4F,0xA1,0xFE,0x9F,0x03,0xE8,0x09,0xF8,0x1F,0xDB,0xF0,0x1F,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0xFF,0xAF,0xC0,0xFF,0xCF,0x03,0xFA,0x00,0xFE,0x3F,0xE3,0xF0,0x7F,0xF7,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0xEE,0x01,0xF0,0x01,0x81,0xC0,0x0D,0x84,0x1E,0x1F,0xFB,0xFE,0x3F,0xF7,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x08,0x00,0xD0,0x01,0xE1,0xC0,0x0C,0x00,0x0E,0x0F,0xF3,0xFC,0x3F,0xF3,0xFF,0x10,0xFF,0xFF,0xFA,0x00,0x00,0x00,0xC0,0x10,0xC1,0xC0,0x04,0x80,0x08,0x0F,0xFF,0xF8,0x3F,0xFF,0xFF,0x00,0x00,0x23,0xFC,0x00,0x00,0x00,0x50,0x02,0x01,0xC0,0x06,0x00,0x0E,0x02,0x4F,0xFC,0x3F,0xBF,0xFF,0x00,0x01,0x30,0x6C,0x00,0x00,0x00,0x50,0x00,0x01,0xC0,0x07,0x10,0x0A,0x00,0x1D,0xFC,0x3F,0x3F,0xFF,0x00,0x07,0xE0,0x18,0x00,0x00,0x00,0x51,0x04,0x01,0xC0,0x06,0x00,0x0E,0x00,0x0F,0xFC,0x3F,0x3F,0xFF,0x00,0x1F,0xF0,0x1C,0x00,0x00,0x00,0x40,0xF4,0x01,0xC0,0x04,0x40,0x0C,0x1E,0x09,0xFC,0x3E,0x3F,0xFF,0x02,0xFB,0x00,0x38,0x00,0x00,0x00,0x70,0x00,0x01,0xC0,0x01,0x80,0x0E,0x21,0x09,0xFC,0x21,0x1F,0xFF,0x07,0xD0,0x0C,0xF0,0x00,0x00,0x00,0xC0,0xFC,0x01,0xC2,0x40,0x00,0x0E,0x3F,0x01,0x7C,0x3F,0x3F,0xFF,0x8F,0x84,0x04,0x30,0x00,0x00,0x00,0x50,0xFE,0x01,0xC3,0xC0,0x80,0x0E,0x3F,0x95,0x7C,0x3F,0xBF,0xFF,0x00,0xC8,0xD1,0x70,0x00,0x00,0x00,0x50,0x06,0x01,0xC0,0x78,0x40,0x0E,0x00,0xC0,0x1C,0x3F,0xBF,0xFF,0x02,0x45,0xE9,0x70,0x00,0x00,0x00,0x40,0x06,0x01,0xE0,0x3E,0x00,0x0E,0x00,0xC0,0x1C,0x3F,0xFF,0xFF,0xF9,0x17,0xE1,0x70,0x00,0x00,0x00,0x70,0x06,0x01,0xC0,0x3E,0x20,0x0A,0x00,0xC0,0x58,0x3F,0xFF,0xFF,0xFC,0x5F,0xE1,0x70,0x00,0x00,0x00,0x40,0x02,0x01,0xE0,0x3F,0x00,0x0E,0x00,0x40,0x1E,0x3F,0xFD,0xFF,0x78,0xFA,0xE0,0x30,0x00,0x00,0x00,0x70,0x00,0x01,0xE0,0x1F,0x80,0x0E,0x00,0x01,0x1E,0x1F,0xF9,0xFF,0x0F,0xE1,0xE0,0xF8,0x00,0x00,0x00,0x61,0x00,0x01,0xA0,0x0F,0x80,0x0C,0x00,0x08,0x1E,0x3F,0xE9,0xFF,0x30,0x15,0xF4,0x78,0x00,0x00,0x00,0x60,0x00,0x01,0x82,0x07,0x04,0x06,0x20,0x26,0x10,0x1F,0xA9,0xFF,0x00,0x10,0x30,0x3C,0x00,0x00,0x01,0x00,0x10,0x00,0x00,0x47,0xC0,0xA0,0x00,0xE4,0x00,0x00,0xE7,0xFF,0x00,0x00,0x00,0x2E,0x00,0x00,0x00,0x34,0x00,0x04,0x30,0x03,0xF2,0x03,0x00,0x1C,0x47,0x00,0x0F,0xFF,0x00,0x00,0x40,0x3C,0x00,0x00,0x01,0xFF,0x00,0x03,0xFC,0x01,0xFE,0x3F,0xF7,0xF8,0x3F,0xFF,0xFF,0xFF,0x00,0x00,0x20,0x16,0x00,0x00,0x03,0xFF,0xE0,0x0F,0xFF,0x01,0xFE,0x7F,0xFF,0xF0,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x80,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xFF,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xFF,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x01,0x00,0x00,0x07,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFF,0x00,0x00,0x00,0x02,0xC0,0x00,0x00,0x0F,0xB0,0x00,0x10,0xF0,0x80,0x00,0x7B,0x00,0x00,0x02,0x81,0xFF,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,0x37,0xD8,0x00,0x30,0x60,0xC0,0x00,0xEF,0x80,0x00,0x04,0x81,0xFF,0x00,0x00,0x00,0x01,0x40,0x00,0x00,0x37,0xD8,0x00,0x30,0x00,0x00,0x01,0xDF,0xE0,0x00,0x1C,0x40,0xFF,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x77,0xDC,0x00,0x30,0x00,0xC0,0x03,0xFF,0xE0,0x00,0x18,0x60,0xFF,0x00,0x00,0x0E,0x70,0x40,0x00,0x00,0x7F,0xF6,0x00,0x38,0x00,0xC0,0x03,0x7F,0xF8,0x00,0x30,0x10,0x7F,0x00,0x00,0x04,0xF3,0xC0,0x00,0x00,0x7F,0xFC,0x00,0x38,0x01,0x80,0x07,0xFF,0xB0,0x00,0x30,0x10,0x7F,0x00,0x00,0x11,0xC2,0x80,0x00,0x00,0xFF,0xFA,0x00,0x1C,0x03,0x80,0x07,0xFF,0xD8,0x00,0x60,0x00,0x7F,0x00,0x00,0x07,0x17,0x00,0x00,0x00,0x3F,0xFC,0x00,0x0E,0x07,0x00,0x05,0xFF,0xF8,0x00,0x30,0x10,0x7F,0x00,0x00,0x00,0x1F,0x00,0x00,0x00,0x7F,0xF4,0x00,0x07,0x0E,0x00,0x05,0xFF,0xF8,0x00,0x38,0x10,0x3F,0x00,0x28,0x04,0x2E,0x00,0x00,0x00,0x27,0x08,0x00,0x03,0x9C,0x00,0x06,0xE9,0xD0,0x00,0x18,0x30,0x3F,0x00,0x40,0x3C,0x0C,0x00,0x00,0x00,0x0B,0xF0,0x00,0x00,0x20,0x00,0x01,0xEF,0xE0,0x00,0x0C,0xC0,0x1F,0x00,0x11,0x34,0x0C,0x00,0x00,0x00,0x0F,0xC0,0x00,0x00,0x00,0x00,0x01,0xFF,0xD0,0x00,0x0A,0x80,0x1F,0x00,0x2F,0xD0,0x1C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x80,0x00,0x00,0x00,0x0F,0x00,0x1F,0x40,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x01,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x0E,0x5C,0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x3C,0x1C,0x00,0x00,0x00,0x02,0x00,0x40,0x07,0xFF,0x80,0x47,0xF2,0x00,0x8F,0xE4,0x00,0x02,0x00,0x00,0x31,0xF8,0x00,0x00,0x00,0x11,0xFF,0x01,0xFE,0x07,0xDC,0x7C,0x04,0x00,0xF8,0x08,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0x00,0x00,0x2B,0x07,0xF0,0x7C,0x0F,0xF4,0x7C,0x18,0x00,0x78,0x30,0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x04,0x01,0xF0,0x0E,0x10,0x3C,0x0E,0x10,0x00,0x1C,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0xF8,0x0F,0x10,0x1C,0x07,0x10,0x00,0x0E,0x20,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0xC0,0x00,0x38,0x04,0x10,0x0C,0x05,0x10,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x03,0x40,0x00,0x1C,0x85,0x10,0x00,0x05,0x10,0x00,0x02,0x20,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x02,0x90,0x00,0x0C,0x84,0x10,0x28,0x04,0x10,0x00,0x06,0x20,0x00,0x00,0x10,0x00,0x00,0x78,0x00,0x00,0x07,0x90,0x00,0x04,0x05,0x10,0x40,0x05,0x10,0x00,0x02,0x24,0x00,0x00,0x38,0x00,0x00,0xF8,0x00,0x00,0x07,0x10,0x00,0x00,0x04,0x0F,0x00,0x04,0x10,0x00,0x00,0x20,0x00,0x00,0x7A,0x00,0x00,0x78,0x00,0x00,0x0F,0x10,0x00,0x00,0x04,0x00,0xC0,0x04,0x10,0x00,0x00,0x20,0x00,0x00,0xFF,0xC0,0x01,0xFC,0x00,0x00,0x0F,0x10,0x00,0x00,0x04,0x0F,0x80,0x04,0x10,0x00,0x02,0x20,0x00,0x00,0x1F,0xFF,0x07,0xDF,0x00,0x00,0x0D,0x10,0x00,0x00,0x05,0x0F,0xE9,0x04,0x10,0x00,0xB2,0x3E,0xC0,0x00,0x01,0x7F,0xFF,0x4F,0x80,0x00,0x0D,0x00,0x00,0x00,0x05,0x10,0x48,0x04,0x10,0x07,0xF2,0x3F,0xF8,0x00,0x01,0xFF,0x00,0x07,0xC0,0x00,0x0F,0x80,0x00,0x00,0x05,0x10,0x68,0x04,0x14,0x3F,0xF2,0x3F,0xFC,0x00,0x31,0xFF,0xE0,0x04,0xFC,0x00,0x0D,0x80,0x00,0x00,0x04,0x10,0x20,0x04,0x1B,0xFF,0xF6,0x3F,0xFD,0x80,0x7F,0xFD,0xC2,0x04,0x3E,0x00,0x0E,0xC4,0x00,0x01,0x86,0x10,0x00,0x85,0x1A,0xDD,0xF0,0x3F,0xEF,0xC0,0xC7,0xFB,0x9F,0x04,0xFE,0x80,0x0F,0x42,0x00,0x02,0x85,0x10,0x00,0x14,0x17,0xFA,0x70,0x3F,0xFC,0xE0,0x0F,0xF4,0xE1,0x04,0x9B,0xC0,0x07,0x60,0x00,0x04,0x04,0x10,0x02,0x4E,0x17,0xEE,0x72,0x3F,0xFC,0xF0,0x1F,0xF2,0x01,0x11,0x1F,0xF4,0x03,0xB0,0x40,0x20,0x06,0x10,0x1A,0xA6,0x1F,0xF0,0xF4,0x1F,0xE1,0xF8,0x1F,0xEC,0x01,0x12,0x0F,0xFC,0x01,0xDC,0x1F,0x08,0x04,0x08,0xCD,0x1E,0x0F,0xC9,0xFC,0x1F,0x93,0xFF,0x3F,0xE8,0x00,0x42,0x2F,0xFE,0x01,0xF8,0x00,0x08,0x10,0x00,0x2A,0x70,0x00,0x29,0xE0,0x00,0x73,0xFF,0x7F,0x90,0x00,0xE4,0x5F,0x1F,0xC0,0x7F,0x3B,0xE0,0x0F,0xFC,0x7C,0x47,0xF0,0x5D,0xC7,0xF0,0x3F,0xFF,0x7F,0x90,0x00,0xC0,0xFF,0x0F,0xE0,0x3F,0xFF,0x80,0x3F,0xFF,0xFB,0xBF,0xFF,0xFB,0xBF,0xFF,0xFF,0xFF,0xFF,0x10,0x00,0xC8,0xBF,0x05,0xF0,0x0F,0xFF,0x00,0x7F,0xFF,0xF1,0xBF,0xFF,0xF7,0xFF,0xFF,0xEF,0xFF,0xFF,0xC8,0x00,0x91,0xFF,0xC1,0xF8,0x00,0x00,0x00,0x00,0x00,0x57,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x01,0x01,0xA1,0xFF,0xF0,0x5F,0x80,0x00,0x00,0x00,0x00,0x6F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x02,0x41,0x60,0xFF,0xF8,0x3F,0x80,0x00,0x00,0x00,0x00,0x53,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x04,0xA1,0x43,0xFF,0xFE,0x1B,0xC0,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x08,0x88,0x87,0xF1,0xFF,0x82,0xFA,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x04,0x80,0x8B,0xF0,0x7F,0xC1,0x7D,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x03,0x81,0x0F,0xF8,0x3F,0xE0,0xBF,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE6,0x10,0x21,0x17,0xFC,0x1F,0xF8,0x7F,0xC0,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE2,0x91,0xD0,0x0F,0xC3,0x07,0xFC,0x1F,0xF8,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0x00,0x42,0x3F,0x81,0xC3,0xFF,0x0F,0xFC,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x78,0x10,0x5F,0x00,0x60,0xFF,0x82,0xFE,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x86,0x08,0x64,0xBF,0x80,0x18,0x3F,0xE0,0xBF,0xE0,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x08,0x08,0xC8,0xFE,0x80,0x0C,0x1F,0xF0,0x5F,0xF0,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x30,0x08,0x09,0x7C,0x83,0x86,0x0F,0xF8,0x2F,0xF8,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x08,0x1E,0xFE,0x84,0x43,0x87,0xFC,0x1F,0xFF,0x23,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x08,0x1C,0xFE,0x00,0x02,0xC1,0xFF,0x87,0xFF,0xCC,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF}, 
title_light92[]={0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x83,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x1F,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x70,0x00,0x00,0x01,0xFF,0xF0,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x1C,0x78,0x00,0x00,0x00,0x3F,0xFE,0x00,0x00,0x01,0xC7,0xC0,0x00,0x00,0x3C,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x1C,0x78,0x00,0x00,0x00,0x3F,0xFE,0x00,0x00,0x01,0xC7,0xC0,0x00,0x00,0x3C,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0xFE,0x00,0xFF,0xF2,0x7F,0x20,0x7F,0xC8,0x1F,0xFF,0xC8,0x1F,0xFF,0x87,0xFC,0x81,0xFF,0xE4,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFC,0x7F,0xE0,0x7F,0xF6,0x07,0xFF,0xF0,0x1F,0xFF,0xC7,0xFF,0x81,0xFF,0xF8,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0xFF,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFE,0x7F,0xD8,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFF,0xC7,0xFF,0x01,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0xFF,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFE,0x7F,0xD8,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFF,0xC7,0xFF,0x01,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF9,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xFE,0x7F,0xD8,0x7F,0xFF,0xC3,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xFF,0xF9,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xFF,0xFF,0xD8,0x7F,0xFF,0xC3,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x07,0xFF,0xF7,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0x8F,0xFF,0xD8,0x7F,0xFF,0xC3,0xFF,0xF6,0x1F,0xFC,0x7F,0xFF,0x61,0xFF,0xC7,0xFF,0xFF,0x00,0x00,0x00,0xE0,0x01,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0x8F,0xFF,0xD8,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFC,0x7F,0xFF,0x61,0xFF,0xC7,0xFF,0xFF,0x00,0x00,0x00,0xE0,0x01,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0x8F,0xFF,0xD8,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFC,0x7F,0xFF,0x61,0xFF,0xC7,0xFF,0xFF,0x00,0x00,0x07,0xFC,0x01,0x8F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0xFF,0x0F,0xFF,0xD8,0x7F,0xF9,0x07,0xFF,0xF6,0x1F,0xF0,0x7F,0xFF,0x61,0xFF,0x07,0xFF,0xFF,0x00,0x00,0x3F,0xFC,0x01,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x0F,0xFF,0xD8,0x7F,0xF0,0x1F,0xFF,0xF6,0x00,0x0C,0x7F,0xFF,0x60,0x00,0xC7,0xFF,0xFF,0x00,0x1F,0xF8,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x40,0xFF,0x0F,0xFF,0xD8,0x00,0x01,0xFF,0xFF,0xF6,0x07,0xE0,0x7F,0xFF,0x60,0x7E,0x1F,0xFF,0xFF,0x00,0x1F,0xF8,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x40,0xFF,0x0F,0xFF,0xD8,0x00,0x01,0xFF,0xFF,0xF6,0x07,0xE0,0x7F,0xFF,0x60,0x7E,0x1F,0xFF,0xFF,0x03,0xFF,0x80,0x00,0x02,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0x8F,0xFF,0xD8,0x1C,0x40,0xFF,0xFF,0xF6,0x1F,0xFC,0x7F,0xFF,0x61,0xFF,0xC7,0xFF,0xFF,0x3F,0xF0,0x07,0xFF,0x0E,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0x8F,0xFF,0xD8,0x7F,0xB0,0x3F,0xFF,0xF6,0x1F,0xFC,0x7F,0xFF,0x61,0xFF,0xC7,0xFF,0xFF,0x00,0x01,0xC0,0x1F,0x0C,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xEF,0xFF,0xD8,0x7F,0xC8,0x1F,0xFF,0xF6,0x1F,0xFE,0x7F,0xFF,0x61,0xFF,0xE7,0xFF,0xFF,0x00,0x1C,0x07,0xFC,0x0C,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xFF,0xFF,0xC0,0x7F,0xC8,0x1F,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0x1C,0x07,0xFC,0x0C,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xFF,0xFF,0xC0,0x7F,0xC8,0x1F,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0xE0,0x3F,0xFC,0x0C,0x3F,0xFF,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFF,0xFF,0xD8,0x7F,0xF6,0x07,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0x01,0xFF,0xFC,0x0C,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC1,0xFF,0xFF,0xFF,0xC0,0x7F,0xF6,0x07,0xFF,0xF6,0x1F,0xFF,0xFF,0xFF,0x01,0xFF,0xFF,0xFF,0xFF,0x00,0xFF,0xF9,0xFC,0x0E,0x3F,0xFF,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFF,0xFF,0xC0,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFF,0xF0,0xFF,0x01,0xFF,0xFF,0x1F,0xFF,0x00,0xFF,0xF9,0xFC,0x0E,0x3F,0xFF,0xFF,0xFF,0xFF,0xFE,0x41,0xFF,0xFF,0xFF,0xC0,0x7F,0xF9,0x03,0xFF,0xF6,0x1F,0xFF,0xF0,0xFF,0x01,0xFF,0xFF,0x1F,0xFF,0x3F,0xFF,0xF8,0xFC,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x40,0xFF,0xFF,0xFF,0xE0,0x7F,0xFE,0xC0,0xFF,0xF6,0x1F,0xFF,0xC9,0xFF,0x01,0xFF,0xFC,0x9F,0xFF,0x03,0xFF,0x86,0xFF,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x40,0xFF,0xFF,0xFF,0x20,0x1F,0xFE,0xE0,0x7F,0xF0,0x07,0xFE,0x31,0xFF,0x81,0xFF,0xE3,0x7F,0xFF,0x00,0x00,0x3F,0xF8,0x01,0x87,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x03,0xFF,0xF8,0x00,0x01,0xFF,0xD8,0x02,0x00,0x00,0x00,0x0F,0xE0,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x18,0x00,0x41,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x03,0xFF,0xF0,0x00,0x01,0xFF,0xE0,0x1E,0x00,0x00,0x00,0x3F,0xC0,0x00,0x00,0x07,0xFF,0xFF,0x00,0x00,0x00,0x18,0x00,0x41,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x03,0xFF,0xF0,0x00,0x01,0xFF,0xE0,0x1E,0x00,0x00,0x00,0x3F,0xC0,0x00,0x00,0x07,0xFF,0xFF,0x00,0x00,0x00,0x18,0x00,0x47,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x20,0x00,0x71,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x38,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x08,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x08,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x0E,0x3F,0xFF,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFF,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0x1F,0xFF,0xFF,0xFF,0xFF,0xCF,0xE3,0xFF,0xFF,0xFB,0xF0,0x3F,0x3F,0xFF,0xFF,0xC3,0x8F,0xFF,0xFF,0xFF,0xF9,0x3F,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0x1F,0xFF,0xFF,0xFF,0xFE,0x3F,0xF8,0xFF,0xFF,0xE3,0xFC,0x7F,0x1F,0xFF,0xFF,0x07,0x83,0xFF,0xFF,0xFF,0xF7,0x3F,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0x1F,0xFF,0xFF,0xFF,0xFE,0x3F,0xF8,0xFF,0xFF,0xE3,0xFC,0x7F,0x1F,0xFF,0xFF,0x07,0x83,0xFF,0xFF,0xFF,0xF7,0x3F,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0xDF,0xFF,0xFF,0xFF,0xFE,0x3F,0xF8,0xFF,0xFF,0xE3,0xFF,0xFF,0xFF,0xFF,0xFE,0x1F,0xE0,0x7F,0xFF,0xFF,0x87,0xDF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0xDF,0xFF,0xFF,0xFF,0xFC,0x3F,0xF8,0x7F,0xFF,0xE3,0xFF,0xFF,0x1F,0xFF,0xF8,0x1F,0xF0,0x7F,0xFF,0xFF,0x8F,0xC7,0xFF,0xFF,0x00,0x00,0x00,0x00,0x01,0x81,0xDF,0xFF,0xFF,0xFF,0xFC,0x7F,0xFF,0x1F,0xFF,0xE0,0xFF,0xFF,0x1F,0xFF,0xF8,0xFF,0xFC,0x0F,0xFF,0xFE,0x3F,0xFB,0xFF,0xFF,0x00,0x00,0x00,0x03,0x03,0x81,0x1F,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0x7F,0xFF,0xE0,0xFF,0xFE,0x3F,0xFF,0xF0,0xFF,0xFE,0x3F,0xFF,0xFE,0x3F,0xFB,0xFF,0xFF,0x00,0x00,0x00,0x03,0x03,0x81,0x1F,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0x7F,0xFF,0xE0,0xFF,0xFE,0x3F,0xFF,0xF0,0xFF,0xFE,0x3F,0xFF,0xFE,0x3F,0xFB,0xFF,0xFF,0x00,0x00,0x00,0x03,0x0F,0x8F,0x3F,0xFF,0xFF,0xFF,0xF3,0xFF,0xFF,0x9F,0xFF,0xF8,0x7F,0xF8,0x3F,0xFF,0xF1,0xFF,0xFF,0x8F,0xFF,0xFC,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x70,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0xFF,0xFC,0x1F,0xF0,0xFF,0xFF,0xF7,0xFF,0xFF,0x8F,0xFF,0xFE,0x3F,0xFB,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x40,0xFF,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0x7F,0xFF,0xFF,0x0F,0xC1,0xFF,0xFF,0xF7,0xFF,0xFF,0x8F,0xFF,0xFE,0x0F,0xFB,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x40,0xFF,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0x7F,0xFF,0xFF,0x0F,0xC1,0xFF,0xFF,0xF7,0xFF,0xFF,0x8F,0xFF,0xFE,0x0F,0xFB,0xFF,0xFF,0x00,0x00,0x40,0x00,0x60,0x41,0xFF,0xFF,0xFF,0xFF,0xFE,0x71,0xFC,0xFF,0xFF,0xFF,0x83,0x87,0xFF,0xFF,0xF1,0xFF,0xFF,0xBF,0xFF,0xFF,0x8F,0xE3,0xFF,0xFF,0x00,0x01,0x80,0x07,0xE0,0x47,0xFF,0xFF,0xFF,0xFF,0xFF,0xCF,0xC3,0xFF,0xFF,0xFF,0xFE,0x7F,0xFF,0xFF,0xFE,0x07,0x80,0x7F,0xFF,0xFF,0xC7,0x1F,0xFF,0xFF,0x00,0x01,0x80,0xFF,0x00,0x47,0xFF,0xFF,0xFF,0xFF,0xFF,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x07,0xE1,0xBF,0xFF,0xFF,0xC9,0x3F,0xFF,0xFF,0x00,0x00,0x41,0xF8,0x01,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x41,0xF8,0x01,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x3F,0xC0,0x03,0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x7F,0x8F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x07,0xF1,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x07,0xF1,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x07,0xE1,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x01,0xFF,0xE0,0x00,0x00,0x00,0x1C,0x00,0x00,0x1F,0xFF,0x00,0x00,0x07,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x0E,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0xFF,0xFC,0x00,0xFF,0x00,0x3F,0xF8,0x1F,0xF6,0x03,0xFF,0xFF,0xFC,0x80,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x0E,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x01,0xFF,0xFE,0x30,0xFF,0x90,0x7F,0xFF,0x1F,0xF9,0x03,0xFF,0xFF,0xFF,0x60,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x47,0xFF,0xFF,0xB8,0xFF,0x90,0x3F,0xFF,0x1F,0xF9,0x03,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x47,0xFF,0xFF,0xB8,0xFF,0x90,0x3F,0xFF,0x1F,0xF9,0x03,0xFF,0xFF,0xFF,0x61,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0xFD,0x8F,0xFF,0xFF,0xC8,0xFF,0x90,0x3F,0xFF,0x1F,0xF9,0x03,0xFF,0xFF,0xFF,0x60,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x03,0xBF,0xFF,0xFF,0xFF,0xFF,0xF2,0x3F,0xFF,0xFF,0xF8,0xFF,0xF0,0x3F,0xFF,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x03,0xBF,0xFF,0xFF,0xFF,0xFF,0xEC,0x3F,0xFF,0xFF,0xF8,0x3F,0xF0,0x3F,0xFF,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x03,0x8F,0xFF,0xFF,0xFF,0xFF,0xEC,0x3F,0xFF,0xFF,0xFE,0x3F,0xF0,0x3F,0xE0,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0x60,0x7F,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x03,0x8F,0xFF,0xFF,0xFF,0xFF,0xEC,0x3F,0xFF,0xFF,0xFE,0x3F,0xF0,0x3F,0xE0,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0x60,0x7F,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x3F,0xC3,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x77,0xFF,0xFF,0xFF,0x3C,0x00,0x00,0x00,0x02,0x0F,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x03,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x0C,0x0F,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x23,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x0C,0x0F,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x23,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x0C,0x07,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x03,0xFF,0xFF,0x03,0xFF,0xFF,0xFF,0xE0,0x7F,0xFF,0xFF,0xFF,0xF8,0x0F,0xFF,0xFF,0xFF,0x80,0xFF,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x7F,0xE0,0xEF,0xFF,0x03,0xFF,0xFF,0x23,0xE0,0x01,0x1F,0xFF,0xFF,0x00,0x0F,0xFF,0xFF,0xFF,0xC0,0x3F,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x3F,0xF8,0xFF,0xFF,0x03,0xFF,0xF0,0x03,0xE0,0x00,0x00,0xFF,0xFF,0x00,0x0F,0xFF,0xFF,0xFF,0xF0,0x1F,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x3F,0xF8,0xFF,0xFF,0x03,0x7E,0x00,0x03,0xE0,0x00,0x00,0x7F,0xFF,0x00,0x0F,0xFF,0xFF,0xFF,0xF0,0x1F,0xFF,0xFF,0xFF,0x90,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x3F,0xF8,0xFF,0xFF,0x03,0x7E,0x00,0x03,0xE0,0x00,0x00,0x7F,0xFF,0x03,0xFF,0xFE,0x07,0xFF,0xF7,0x00,0x7F,0xFF,0xFF,0xEC,0x0F,0xFF,0xFF,0xFF,0xFF,0xF0,0x3F,0xFF,0xFF,0xFF,0x00,0x80,0x00,0x03,0x60,0x00,0x00,0x63,0xFF,0xFF,0xFF,0xFE,0x1F,0x9F,0xF7,0xE0,0x1F,0xFF,0xFF,0xEC,0x07,0xFF,0xFF,0xFE,0x3F,0x90,0x3F,0xFF,0xF3,0xFF,0x00,0x91,0x86,0x03,0xE0,0x00,0x04,0x01,0xFF,0xFF,0xFF,0xF8,0x38,0x0F,0xF7,0x00,0x13,0xFF,0xFF,0xEE,0x01,0xFF,0xFF,0xF8,0x3F,0xF0,0x3F,0xFF,0xE3,0xBF,0x03,0x00,0x08,0x03,0xE0,0x00,0x00,0x00,0x7F,0xFF,0xFF,0xF8,0x38,0x0F,0xF7,0x00,0x13,0xFF,0xFF,0xEE,0x01,0xFF,0xFF,0xF8,0x3F,0xF0,0x3F,0xFF,0xE3,0xBF,0x03,0x00,0x08,0x03,0xE0,0x00,0x00,0x00,0x7F,0xFF,0xFF,0xF7,0x00,0x0F,0xF7,0x00,0x81,0xFF,0xFF,0xF2,0x01,0xFF,0xFF,0xF0,0xFF,0xF0,0x3F,0xFF,0x81,0xC9,0x03,0x00,0x40,0x03,0xE0,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xF8,0x00,0x0F,0xBE,0x03,0xF0,0x37,0xFF,0xFE,0x40,0x1F,0xFE,0x07,0xFF,0x90,0x3F,0xF8,0x62,0x79,0x00,0x00,0x06,0x03,0x60,0x00,0x00,0x80,0x0F,0xFF,0xFF,0xC0,0x00,0x0F,0xB8,0x07,0xFC,0x07,0xFF,0xFF,0xB0,0x00,0x00,0x0F,0xFF,0x60,0x0F,0x00,0x8F,0x80,0x00,0x00,0x08,0x00,0x00,0x00,0x03,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x0D,0xF8,0x07,0xFE,0x01,0xFF,0xFF,0xCE,0x00,0x00,0x7F,0xF8,0x00,0x00,0x04,0x1C,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x60,0x00,0xFF,0xFF,0xC0,0x00,0x0D,0xF8,0x07,0xFE,0x01,0xFF,0xFF,0xCE,0x00,0x00,0x7F,0xF8,0x00,0x00,0x04,0x1C,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x60,0x00,0xFF,0xFF,0x80,0x00,0x00,0x70,0x1F,0xFF,0xF0,0x1F,0xFF,0xFF,0xE0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFD,0xFF,0xFF,0xFF,0xFE,0x1F,0xFF,0xFF,0xFF,0x80,0x00,0xFF,0xFF,0x80,0x00,0x01,0xF0,0x1F,0xFF,0xF8,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x83,0xFF,0xFF,0xFF,0xF8,0x3F,0xFF,0xFF,0xFF,0x00,0x00,0xFF,0xFF,0x80,0x00,0x01,0xC0,0x3F,0xFF,0xFE,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE3,0xFF,0xFF,0xFF,0xF0,0x3F,0xFF,0xFF,0xFC,0x00,0x00,0xFF,0xFF,0x80,0x00,0x01,0xC0,0x3F,0xFF,0xFE,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE3,0xFF,0xFF,0xFF,0xF0,0x3F,0xFF,0xFF,0xFC,0x00,0x00,0xFF,0xF1,0xC0,0x00,0x03,0x80,0x3F,0xFF,0xFF,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xDB,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFE,0x00,0x02,0x00,0xFF,0xFF,0xFF,0xF8,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xF8,0x00,0x0C,0x01,0xFF,0xFF,0xFF,0xFC,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xDB,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xF0,0x20,0x0C,0x01,0xFF,0xFF,0xFF,0xFF,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xF0,0x20,0x0C,0x01,0xFF,0xFF,0xFF,0xFF,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x3C,0xF0,0x07,0xFF,0xFF,0xFF,0xFF,0xF0,0x09,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xF0,0x3F,0xF0,0x0F,0xFF,0xFF,0xFF,0xFF,0xFC,0x06,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xF8,0x3F,0xE0,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x1F,0xBF,0xE7,0xE0,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x1F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x1F,0xBF,0xE7,0xE0,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x1F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x93,0xBE,0x1B,0xE0,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xEF,0xFF,0xDF,0x80,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x7F,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFC,0x0F,0xFB,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x1F,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFC,0x0F,0xFB,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x1F,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x0F,0xC7,0x03,0xFE,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x7F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFC,0x00,0x0F,0x1C,0x03,0xFE,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x3F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE0,0x00,0x0F,0xFC,0x0F,0xFE,0x3F,0x83,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x0F,0xFF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE0,0x00,0x0F,0xF8,0x1F,0xF8,0x3F,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0xE7,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE0,0x00,0x0F,0xF8,0x1F,0xF8,0x3F,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0xE7,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF8,0x7F,0xF0,0x3F,0x01,0xF8,0x3F,0xFF,0xFF,0xFF,0xE0,0x00,0x1C,0x72,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, 
title_dark92[]={0xFB,0x7F,0x81,0x00,0x0E,0x30,0xFF,0xE1,0xF7,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x01,0xFF,0x81,0xB8,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x01,0xFF,0x81,0xB8,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x07,0xFF,0x02,0x78,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x0F,0xFC,0x1F,0xF0,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x3F,0xF8,0x73,0xC0,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x7F,0xE0,0xFE,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0x80,0x00,0x00,0x7F,0xE0,0xFE,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0x80,0x00,0x00,0x7F,0xC0,0x9C,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xC0,0x00,0x01,0xFF,0x07,0x7C,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xE0,0x03,0xFE,0x1F,0xE0,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xE0,0x03,0xFE,0x1F,0xE0,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xFF,0xFF,0xF8,0x1B,0x80,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x1F,0xFF,0xFF,0xFF,0xF0,0x27,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x1F,0xFF,0xFF,0xFF,0xF0,0xFF,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0xFF,0xFF,0x81,0x3C,0x00,0x0F,0xFF,0x7E,0x76,0x3B,0x91,0x86,0xFB,0x6C,0x7F,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0xFF,0xFF,0x81,0x3C,0x00,0x0F,0xFF,0x7E,0x76,0x3B,0x91,0x86,0xFB,0x6C,0x7F,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x0F,0x87,0xF8,0x00,0x3F,0xD8,0xE3,0xC7,0x20,0xE2,0x71,0x18,0x92,0x01,0xDB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x06,0xE0,0x00,0x7F,0x27,0x1C,0x4E,0xC7,0x02,0x06,0x00,0x60,0x47,0x24,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x09,0xE0,0x00,0x7F,0xF8,0x00,0x00,0x00,0x00,0x30,0x00,0x00,0x06,0x1C,0x9C,0x00,0x00,0x00,0x0F,0xC0,0x60,0x06,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x3F,0xC0,0x00,0x7F,0xC3,0x90,0x00,0x00,0x60,0x76,0x00,0x00,0x00,0x03,0x1D,0x80,0x00,0x02,0x07,0xF8,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x3F,0xC0,0x00,0x7F,0xC3,0x90,0x00,0x00,0x60,0x76,0x00,0x00,0x00,0x03,0x1D,0x80,0x00,0x02,0x07,0xF8,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF7,0xC0,0x01,0xFF,0x23,0xFD,0x81,0xFF,0xEC,0x7F,0x00,0x7F,0xB0,0x03,0x1F,0xF0,0x07,0xFE,0x77,0xFC,0x00,0x7F,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x0F,0xFF,0xDB,0xFE,0x00,0xFF,0xFE,0x3F,0x00,0x7F,0xF6,0x00,0x0F,0xFE,0x1F,0xFF,0x87,0xFC,0x03,0xFF,0xFC,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x0F,0xBE,0x00,0x1F,0xC0,0x00,0x1C,0x01,0xE0,0x00,0x39,0xC0,0x80,0x7E,0x07,0xFF,0xF7,0xFF,0xE1,0xFF,0xFC,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x0F,0xBE,0x00,0x1F,0xC0,0x00,0x1C,0x01,0xE0,0x00,0x39,0xC0,0x80,0x7E,0x07,0xFF,0xF7,0xFF,0xE1,0xFF,0xFC,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x30,0x00,0x0E,0x40,0x00,0x1F,0x81,0xE0,0x00,0x38,0x00,0x00,0x3E,0x03,0xFF,0xC7,0xFF,0x81,0xFF,0xFC,0x7F,0xFF,0x04,0x0F,0xFF,0xFF,0xFF,0xF6,0x00,0x00,0x00,0x00,0x0E,0x00,0x04,0x0E,0x01,0xE0,0x00,0x08,0xC0,0x00,0x30,0x03,0xFF,0xFF,0xFF,0x01,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x18,0x7F,0xF8,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x60,0x01,0xE0,0x00,0x0E,0x00,0x00,0x3E,0x00,0x62,0x3F,0xFF,0x81,0xFF,0xDF,0xFF,0xFF,0x00,0x00,0x01,0x1C,0x03,0xB8,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x00,0x01,0xE0,0x00,0x0F,0x04,0x00,0x36,0x00,0x00,0x79,0xFF,0x81,0xFF,0x1F,0xFF,0xFF,0x00,0x00,0x01,0x1C,0x03,0xB8,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x00,0x01,0xE0,0x00,0x0F,0x04,0x00,0x36,0x00,0x00,0x79,0xFF,0x81,0xFF,0x1F,0xFF,0xFF,0x00,0x00,0x0F,0xF8,0x00,0x70,0x00,0x00,0x00,0x00,0x02,0x41,0x00,0x80,0x01,0xE0,0x00,0x0E,0x00,0x00,0x3E,0x00,0x00,0x3F,0xFF,0x81,0xFF,0x1F,0xFF,0xFF,0x00,0x00,0x7F,0xFC,0x00,0x78,0x00,0x00,0x00,0x00,0x02,0x00,0xFC,0x80,0x01,0xE0,0x00,0x08,0x20,0x00,0x38,0x07,0xE0,0x31,0xFF,0x81,0xFE,0x1F,0xFF,0xFF,0x00,0x6F,0xF7,0x00,0x01,0xF0,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,0x01,0xE0,0x00,0x01,0xC0,0x00,0x3E,0x18,0x10,0x31,0xFF,0x81,0x81,0x07,0xFF,0xFF,0x00,0x6F,0xF7,0x00,0x01,0xF0,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,0x01,0xE0,0x00,0x01,0xC0,0x00,0x3E,0x18,0x10,0x31,0xFF,0x81,0x81,0x07,0xFF,0xFF,0x00,0xFE,0x40,0x03,0x8F,0xC0,0x00,0x00,0x00,0x00,0x0E,0x00,0xFF,0x80,0x01,0xE0,0x62,0x00,0x00,0x00,0x3E,0x1F,0xF0,0x01,0x3F,0x81,0xFF,0x1F,0xFF,0xFF,0xC3,0xFC,0x08,0x00,0x81,0xC0,0x00,0x00,0x00,0x00,0x02,0x40,0xFF,0xE0,0x01,0xE0,0x7E,0x00,0xC0,0x00,0x3E,0x1F,0xFC,0x49,0x3F,0x81,0xFF,0xDF,0xFF,0xFF,0x00,0x0E,0x30,0xE4,0x13,0xC0,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0xE0,0x01,0xE0,0x03,0xF0,0x20,0x00,0x3E,0x00,0x0E,0x00,0x07,0x81,0xFF,0xDF,0xFF,0xFF,0x00,0x62,0x09,0xFB,0x13,0xC0,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0xE0,0x01,0xF8,0x01,0xFE,0x00,0x00,0x3E,0x00,0x0E,0x00,0x07,0x81,0xFF,0xFF,0xFF,0xFF,0x00,0x62,0x09,0xFB,0x13,0xC0,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0xE0,0x01,0xF8,0x01,0xFE,0x00,0x00,0x3E,0x00,0x0E,0x00,0x07,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0x10,0x4F,0xF8,0x13,0xC0,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0xE0,0x01,0xE0,0x01,0xFE,0x18,0x00,0x36,0x00,0x0E,0x00,0x27,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0x82,0x7F,0xF8,0x13,0xC0,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x60,0x01,0xF8,0x01,0xFF,0x00,0x00,0x3E,0x00,0x02,0x00,0x07,0xE1,0xFF,0xFF,0x9F,0xFF,0x3F,0x0F,0xF6,0xF8,0x01,0xC0,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,0x01,0xF8,0x00,0x7F,0xC0,0x00,0x3E,0x00,0x00,0x01,0x07,0xE0,0x7F,0xFF,0x1F,0xFF,0x3F,0x0F,0xF6,0xF8,0x01,0xC0,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,0x01,0xF8,0x00,0x7F,0xC0,0x00,0x3E,0x00,0x00,0x01,0x07,0xE0,0x7F,0xFF,0x1F,0xFF,0x03,0xFF,0x81,0xF8,0x0F,0xF0,0x00,0x00,0x00,0x00,0x03,0x81,0x00,0x00,0x01,0xD8,0x00,0x3F,0xC0,0x00,0x38,0x00,0x00,0x30,0x07,0xE1,0xFF,0xFB,0x1F,0xFF,0x1C,0x00,0x49,0xFC,0x83,0xF0,0x00,0x00,0x00,0x00,0x03,0x80,0x00,0x00,0x01,0xC0,0x60,0x0F,0x00,0x80,0x0E,0x18,0x01,0x8E,0x04,0x00,0x7F,0xDB,0x1F,0xFF,0x00,0x00,0x40,0x1C,0x01,0xF8,0x00,0x00,0x00,0x00,0x10,0x00,0x04,0x00,0x00,0x00,0x02,0x0F,0xE0,0x0D,0x80,0x00,0x0F,0x88,0x00,0x00,0x00,0xF8,0xFF,0xFF,0x00,0x00,0x00,0x00,0x01,0xBE,0x00,0x00,0x00,0x00,0x01,0xC8,0x00,0x00,0x08,0x1C,0x00,0x07,0xFC,0x60,0x07,0x00,0x00,0x78,0x20,0xF0,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0x00,0x01,0xBE,0x00,0x00,0x00,0x00,0x01,0xC8,0x00,0x00,0x08,0x1C,0x00,0x07,0xFC,0x60,0x07,0x00,0x00,0x78,0x20,0xF0,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0x20,0x01,0xF8,0x00,0x00,0x00,0x00,0x1F,0xFF,0x00,0x00,0x07,0xFF,0x80,0x01,0xFF,0xE1,0xFF,0xFC,0xFF,0xF0,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x18,0x00,0x4E,0x00,0x00,0x00,0x00,0x7F,0xFF,0xF8,0x00,0x3F,0xFF,0xF0,0x01,0xFF,0xE3,0xFF,0xFF,0xFF,0xC0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0xC0,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0xC0,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0xFF,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x06,0xE0,0x00,0x00,0x00,0x00,0x3F,0xDC,0x00,0x00,0x04,0x0F,0xC0,0xC0,0x00,0x00,0x3F,0x70,0x00,0x00,0x00,0x06,0xC0,0x1F,0xFF,0x00,0x00,0x00,0x00,0x00,0x07,0xE0,0x00,0x00,0x00,0x01,0xCF,0xE7,0x00,0x00,0x1C,0x03,0x80,0xE0,0x00,0x00,0xFB,0xFC,0x00,0x00,0x00,0x08,0xC0,0x1F,0xFF,0x00,0x00,0x00,0x00,0x00,0x07,0xE0,0x00,0x00,0x00,0x01,0xCF,0xE7,0x00,0x00,0x1C,0x03,0x80,0xE0,0x00,0x00,0xFB,0xFC,0x00,0x00,0x00,0x08,0xC0,0x1F,0xFF,0x00,0x00,0x00,0x00,0x00,0x01,0x20,0x00,0x00,0x00,0x01,0xCF,0xE7,0x00,0x00,0x1C,0x00,0x00,0x00,0x00,0x01,0xE7,0xFF,0x80,0x00,0x00,0x78,0x20,0x0F,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x03,0xCF,0xE7,0x80,0x00,0x1C,0x00,0x00,0xE0,0x00,0x07,0xFF,0xFF,0x80,0x00,0x00,0x70,0x38,0x0F,0xFF,0x00,0x00,0x00,0x03,0xE3,0xC0,0x20,0x00,0x00,0x00,0x03,0xFF,0xFC,0xE0,0x00,0x1F,0x00,0x00,0xE0,0x00,0x07,0x3F,0xFF,0xF0,0x00,0x01,0xC0,0x04,0x03,0xFF,0x00,0x00,0x00,0x00,0x8F,0xC7,0xE0,0x00,0x00,0x00,0x03,0xFF,0xFF,0x80,0x00,0x1F,0x00,0x01,0xC0,0x00,0x0F,0xFF,0xFD,0xC0,0x00,0x01,0xC0,0x04,0x03,0xFF,0x00,0x00,0x00,0x00,0x8F,0xC7,0xE0,0x00,0x00,0x00,0x03,0xFF,0xFF,0x80,0x00,0x1F,0x00,0x01,0xC0,0x00,0x0F,0xFF,0xFD,0xC0,0x00,0x01,0xC0,0x04,0x03,0xFF,0x00,0x00,0x00,0x04,0x1E,0x06,0xC0,0x00,0x00,0x00,0x0F,0xFF,0xFF,0x60,0x00,0x07,0x80,0x07,0xC0,0x00,0x0F,0xFF,0xFE,0x70,0x00,0x03,0x80,0x00,0x03,0xFF,0x00,0x00,0x00,0x00,0xF0,0x4F,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0x80,0x00,0x03,0xE0,0x0F,0x00,0x00,0x09,0xFF,0xFF,0xF0,0x00,0x01,0xC0,0x04,0x03,0xFF,0x00,0x00,0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x00,0x03,0xFF,0xFC,0x80,0x00,0x00,0xF0,0x3E,0x00,0x00,0x09,0xFF,0xFF,0xF0,0x00,0x01,0xF0,0x04,0x01,0xFF,0x00,0x00,0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x00,0x03,0xFF,0xFC,0x80,0x00,0x00,0xF0,0x3E,0x00,0x00,0x09,0xFF,0xFF,0xF0,0x00,0x01,0xF0,0x04,0x01,0xFF,0x00,0x01,0xB0,0x00,0x81,0xBE,0x00,0x00,0x00,0x00,0x01,0x8F,0x03,0x00,0x00,0x00,0x7C,0x78,0x00,0x00,0x0E,0xFB,0x1E,0x40,0x00,0x00,0x70,0x1C,0x01,0xFF,0x00,0x02,0x00,0x1F,0x80,0x38,0x00,0x00,0x00,0x00,0x00,0x37,0xFC,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x01,0xFB,0xFF,0x80,0x00,0x00,0x38,0xE0,0x00,0x7F,0x00,0x00,0x41,0x1C,0x80,0x38,0x00,0x00,0x00,0x00,0x00,0x3F,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFE,0x40,0x00,0x00,0x36,0xC0,0x00,0x7F,0x00,0x01,0xBF,0xE4,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x01,0xBF,0xE4,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x7F,0x20,0x01,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x1C,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x03,0xE2,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x03,0xE2,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x1F,0x80,0x78,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x02,0x00,0x00,0xFF,0xFF,0xC0,0x02,0x0F,0xFC,0x60,0x00,0xC3,0xFF,0x88,0x00,0x00,0x06,0x00,0x00,0x00,0x1C,0x1F,0xF0,0x00,0x00,0x00,0x00,0x00,0x41,0xFF,0xF0,0x01,0xFF,0xE0,0x0F,0xE7,0x83,0xF8,0x00,0x80,0x00,0xFF,0x00,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF0,0x00,0x00,0x00,0x00,0x01,0xB7,0x00,0xFF,0xC0,0x3F,0x80,0x3F,0xFC,0x83,0xF8,0x07,0x00,0x00,0x3F,0x01,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF0,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1F,0xC0,0x03,0xE0,0x40,0x1F,0x80,0x3E,0x04,0x00,0x00,0x07,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF0,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1F,0xC0,0x03,0xE0,0x40,0x1F,0x80,0x3E,0x04,0x00,0x00,0x07,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF0,0x03,0xF0,0x40,0x07,0x80,0x0F,0x04,0x00,0x00,0x03,0xE1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x0E,0x00,0x00,0x01,0xF0,0x00,0x80,0x40,0x03,0x80,0x09,0x04,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x72,0x00,0x00,0x00,0x78,0xC0,0x90,0x40,0x00,0x00,0x09,0x04,0x00,0x00,0x00,0x61,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x00,0x6C,0x40,0x00,0x00,0x38,0xC0,0x80,0x40,0x1B,0x00,0x08,0x04,0x00,0x00,0x00,0xE1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,0x00,0x00,0x00,0x6C,0x40,0x00,0x00,0x38,0xC0,0x80,0x40,0x1B,0x00,0x08,0x04,0x00,0x00,0x00,0xE1,0x80,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x03,0xF0,0x00,0x00,0x00,0x00,0xFC,0x40,0x00,0x00,0x08,0x00,0x90,0x40,0x20,0x00,0x09,0x04,0x00,0x00,0x00,0x61,0x88,0x00,0x00,0x00,0x1F,0x00,0x00,0x00,0x0F,0xF0,0x00,0x00,0x00,0x00,0xF0,0x40,0x00,0x00,0x00,0x00,0x80,0x3F,0x00,0x00,0x08,0x04,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x00,0x3F,0x60,0x00,0x00,0x03,0xF0,0x00,0x00,0x00,0x03,0xF0,0x40,0x00,0x00,0x00,0x00,0x80,0x00,0xE0,0x00,0x08,0x04,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x00,0x3F,0x60,0x00,0x00,0x03,0xF0,0x00,0x00,0x00,0x03,0xF0,0x40,0x00,0x00,0x00,0x00,0x80,0x00,0xE0,0x00,0x08,0x04,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x00,0xFF,0xFE,0x00,0x00,0x1F,0xF8,0x00,0x00,0x00,0x03,0xF0,0x40,0x00,0x00,0x00,0x00,0x80,0x3F,0xC0,0x00,0x08,0x04,0x00,0x00,0x00,0x61,0x80,0x00,0x00,0x00,0x07,0xFF,0xFF,0x00,0xFE,0x7F,0x00,0x00,0x00,0x03,0x90,0x40,0x00,0x00,0x00,0x00,0x90,0x3F,0xFB,0x10,0x08,0x04,0x00,0x00,0xDC,0x61,0xFE,0xE0,0x00,0x00,0x00,0x13,0xFF,0xFF,0xF2,0x3F,0xC0,0x00,0x00,0x03,0x90,0x00,0x00,0x00,0x00,0x00,0x90,0x40,0x23,0x00,0x08,0x04,0x00,0x0F,0xFC,0x61,0xFF,0xFF,0x00,0x00,0x00,0x1F,0xFF,0x00,0x00,0x0F,0xE0,0x00,0x00,0x03,0xFC,0x00,0x00,0x00,0x00,0x00,0x90,0x40,0x3B,0x00,0x08,0x04,0x81,0xFF,0xFC,0x61,0xFF,0xFF,0x80,0x00,0x00,0x1F,0xFF,0x00,0x00,0x0F,0xE0,0x00,0x00,0x03,0xFC,0x00,0x00,0x00,0x00,0x00,0x90,0x40,0x3B,0x00,0x08,0x04,0x81,0xFF,0xFC,0x61,0xFF,0xFF,0x80,0x00,0x1C,0x1F,0xFF,0xF8,0x00,0x08,0xFF,0x80,0x00,0x03,0x9C,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x18,0x00,0x08,0x07,0x7F,0xFF,0xFC,0xE1,0xFF,0xFF,0x9C,0x00,0x3F,0xFF,0xF9,0xE0,0x60,0x08,0x1F,0xE0,0x00,0x03,0xEE,0x08,0x00,0x00,0x01,0xC0,0xE0,0x40,0x00,0x0C,0x09,0x07,0x6E,0x79,0xFC,0x01,0xFF,0xFB,0xFE,0x00,0xE0,0xFF,0xF7,0xC7,0xF0,0x08,0xFF,0xEC,0x00,0x03,0xF2,0x06,0x00,0x00,0x06,0xC0,0x90,0x40,0x00,0x00,0x48,0x04,0xFF,0xF6,0x3C,0x01,0xFF,0xFF,0x8F,0x80,0xE0,0xFF,0xF7,0xC7,0xF0,0x08,0xFF,0xEC,0x00,0x03,0xF2,0x06,0x00,0x00,0x06,0xC0,0x90,0x40,0x00,0x00,0x48,0x04,0xFF,0xF6,0x3C,0x01,0xFF,0xFF,0x8F,0x80,0x03,0xFF,0xC8,0xF8,0x10,0x08,0xC7,0x7E,0x00,0x00,0xF3,0x80,0x00,0x00,0x08,0x00,0x80,0x40,0x00,0x62,0x3E,0x04,0xFF,0xBE,0x3C,0x61,0xFF,0xFF,0x8F,0xC0,0x07,0xFF,0xC6,0x00,0x10,0x41,0x07,0xFF,0xC8,0x00,0x7D,0xC0,0x20,0x01,0x80,0x00,0xE0,0x40,0x07,0x6D,0x8E,0x07,0xFF,0xC0,0xFC,0x80,0x7F,0xF8,0x1F,0xF0,0x07,0xFF,0xB8,0x00,0x10,0x46,0x03,0xFF,0xF8,0x00,0x1E,0x78,0x07,0xF0,0x30,0x00,0x80,0x30,0xE3,0x90,0x7E,0x03,0xFE,0x31,0xFF,0x80,0x7F,0xC4,0x7F,0xFF,0x1F,0xFF,0xB0,0x00,0x02,0x06,0x1B,0xFF,0xFE,0x00,0x1F,0xF0,0x00,0x00,0x30,0x04,0x00,0x00,0x1B,0x63,0xC0,0x00,0x01,0xB1,0xF8,0x00,0x00,0x3C,0x7F,0xFF,0x1F,0xFF,0xB0,0x00,0x02,0x06,0x1B,0xFF,0xFE,0x00,0x1F,0xF0,0x00,0x00,0x30,0x04,0x00,0x00,0x1B,0x63,0xC0,0x00,0x01,0xB1,0xF8,0x00,0x00,0x3C,0x7F,0xFF,0x3F,0xFC,0x40,0x00,0x0F,0x88,0x27,0xF0,0x7F,0xE0,0x03,0xFF,0x1F,0x7F,0x80,0x03,0xFF,0xF8,0x3F,0x82,0x0F,0xFC,0x02,0x79,0xE0,0xFF,0xC0,0x1F,0xFF,0xFF,0x3F,0xFC,0x40,0x00,0x0E,0x00,0xFF,0xF0,0x3F,0xF8,0x01,0xFF,0xFF,0xFC,0x00,0x1F,0xFF,0xFF,0xFF,0x7D,0xFF,0xFF,0xFF,0xF7,0xDF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x40,0x00,0x0E,0x30,0xDF,0xF0,0x09,0xFC,0x00,0x3F,0xFF,0xF0,0x00,0x3F,0xFF,0xFF,0xFC,0x1D,0xFF,0xFF,0xFF,0xCF,0xFF,0xFF,0xFF,0xFB,0xFF,0xFF,0xFF,0xF0,0x40,0x00,0x0E,0x30,0xDF,0xF0,0x09,0xFC,0x00,0x3F,0xFF,0xF0,0x00,0x3F,0xFF,0xFF,0xFC,0x1D,0xFF,0xFF,0xFF,0xCF,0xFF,0xFF,0xFF,0xFB,0xFF,0xFF,0xFF,0xFE,0x30,0x00,0x0C,0x41,0xFF,0xFE,0x01,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x01,0x00,0x1D,0x81,0xFF,0xFF,0xC0,0x27,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3B,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x06,0x20,0x13,0x80,0xFF,0xFF,0xF0,0x1F,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x7D,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x08,0xD8,0x12,0x07,0xFF,0xFF,0xFE,0x07,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x08,0xD8,0x12,0x07,0xFF,0xFF,0xFE,0x07,0x7E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x30,0xC3,0x0C,0x0F,0xFC,0x1F,0xFF,0xC0,0x6F,0xF6,0x00,0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x08,0xC0,0x0C,0x37,0xFC,0x03,0xFF,0xE0,0x13,0xF9,0x00,0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x07,0xC0,0x10,0x3F,0xFF,0x01,0xFF,0xF8,0x0D,0xFF,0x00,0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0xE0,0x40,0x18,0x10,0x4F,0xFF,0x80,0x7F,0xFF,0x03,0xFF,0xE0,0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0xE0,0x40,0x18,0x10,0x4F,0xFF,0x80,0x7F,0xFF,0x03,0xFF,0xE0,0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x6C,0x41,0xE4,0x00,0x3F,0xE0,0x70,0x0F,0xFF,0x80,0x7F,0xFF,0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x10,0x00,0x20,0x61,0xFF,0xC0,0x1E,0x07,0xFF,0xF0,0x3F,0xFF,0x80,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x03,0xF0,0x04,0x02,0x7F,0x00,0x03,0x80,0xFF,0xFC,0x06,0xFF,0xE0,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x03,0xF0,0x04,0x02,0x7F,0x00,0x03,0x80,0xFF,0xFC,0x06,0xFF,0xE0,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0xE0,0x30,0x38,0x8D,0xFF,0xC0,0x00,0x70,0x1F,0xFF,0x80,0xDF,0xFF,0x80,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x03,0x00,0x30,0xE3,0x0F,0xFE,0xC0,0x00,0x38,0x07,0xFF,0xC0,0x27,0xFF,0xC0,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x1C,0x00,0x30,0x03,0x13,0xF8,0xC0,0x7C,0x0E,0x03,0xFF,0xF0,0x1B,0xFF,0xF0,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x30,0x07,0xEF,0xFE,0xC0,0x82,0x07,0xC0,0xFF,0xF8,0x07,0xFF,0xFF,0x18,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x30,0x07,0xEF,0xFE,0xC0,0x82,0x07,0xC0,0xFF,0xF8,0x07,0xFF,0xFF,0x18,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x30,0x07,0x8F,0xFE,0x00,0x00,0x06,0xE0,0x1F,0xFF,0xC0,0xFF,0xFF,0xE3,0x8D,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
#define title_light (TI89?title_light89:title_light92)
#define title_dark (TI89?title_dark89:title_dark92)

// Card Variables
const unsigned char suit_sprite[][16]={{0x18,0x3C,0x3C,0x7E,0x7E,0x7E,0x18,0x3C,0x18,0x3C,0x3C,0x7E,0x7E,0x7E,0x18,0x3C},{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x7E,0x7E,0x7E,0x3C,0x3C,0x18,0x18},{0x18,0x3C,0x5A,0xFF,0xFF,0x5A,0x18,0x3C,0x18,0x3C,0x5A,0xFF,0xFF,0x5A,0x18,0x3C},{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x38,0x7C,0x7C,0x38,0x38,0x10}};
const char *ranks[]={"A","2","3","4","5","6","7","8","9","10","J","Q","K"};

void _main(void)
{
	// Variables
	SAVE_GAME_TEMPLATE *game=NULL;
	SYM_ENTRY *file=NULL;
	char *buffer=NULL;
	if((game=(SAVE_GAME_TEMPLATE *)malloc(sizeof(SAVE_GAME_TEMPLATE)))==NULL || (buffer=(char *)malloc(3*LCD_SIZE))==NULL)
		exit(0);
	short int counter=0, counter2, counter3, menu_choice, option=0;
	// Interrupt Handlers
	INT_HANDLER save_int_1, save_int_5;
	if((file=SymFindPtr(SYMSTR("freecsav"), 0))==NULL || file->handle==H_NULL)
	{
		game->in_progress=game->win=game->loss=game->streak_win=game->streak_loss=game->streak_current=game->score=0;
		game->best_score=-35;
		game->stagger=8;
		game->last_result=NO_GAME;
		game->dummy=52;
		for(; counter<=51; counter++)
			game->deck[counter]=counter;
	}
	else
		memcpy(game, HeapDeref(file->handle)+2, sizeof(SAVE_GAME_TEMPLATE));
	memcpy(buffer, LCD_MEM, LCD_SIZE);
	// Save the interrupts
	save_int_1=GetIntVec(AUTO_INT_1);
	save_int_5=GetIntVec(AUTO_INT_5);
	// Redirect the Interrupts
	SetIntVec(AUTO_INT_1, DUMMY_HANDLER);
	SetIntVec(AUTO_INT_5, DUMMY_HANDLER);
	// Seed the random number generator
	randomize();
	while(1)
	{
		until_unpressed(RR_ENTER);
		clrscr();
		if(!GrayOn())
		{
			free(game);
			free(buffer);
			return;
		}
		// Title Screen
		GraySpriteX8_OR(0, 0, LCD_HEIGHT, title_light, title_dark, LCD_WIDTH/8, GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE));
		GrayDrawStrExt(LCD_WIDTH-66, LCD_HEIGHT-8, "   Start   ", A_REPLACE, F_6x8);
		GrayDrawStrExt(0, LCD_HEIGHT-5, ".94", A_REPLACE, F_4x6);
		menu_choice=0;
		do
		{
			if(_keytest(RR_UP))
			{
				GrayDrawStrExt(LCD_WIDTH-66, LCD_HEIGHT-8, ((char[][12]){"   Start   ", "   Stats   ",  "How To Play", "   About   "})[menu_choice+=menu_choice?-1:3], A_REPLACE, F_6x8);
				delay_key(4000, RR_UP);
			}
			if(_keytest(RR_DOWN))
			{
				GrayDrawStrExt(LCD_WIDTH-66, LCD_HEIGHT-8, ((char[][12]){"   Start   ", "   Stats   ", "How To Play", "   About   "})[menu_choice=(menu_choice+1)%4], A_REPLACE, F_6x8);
				delay_key(4000, RR_DOWN);
			}
			if(_keytest(RR_ESC))
			{
				menu_choice=4;
				break;
			}
		}while(!_keytest(RR_ENTER));
		until_unpressed(RR_ENTER);
		if(menu_choice)
			GrayOff();
		clrscr();
		if(menu_choice==0)
		{
			GrayClearScreen();
			if(game->in_progress==0)
			{
				shuffle(game->deck);
				deal_cards(game);
			}
			draw_tableau(game, buffer+LCD_SIZE);
			do
			{
				determine_empty(game);
				if(game->score>game->best_score)
					game->best_score=game->score;
				sprintf(buffer+LCD_SIZE, "%ld", game->score);
				GrayDrawStrExt(0, 20, buffer+LCD_SIZE, A_CENTERED | A_REPLACE, F_4x6);
				if(_keytest(RR_PLUS) && game->stagger<8)
				{
					game->stagger++;
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_MINUS) && game->stagger>3)
				{
					game->stagger--;
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_2ND))
				{
					if(game->cursor[0]==8)
					{
						if(game->selected[0]==8)
						{
							if(game->selected[1]==game->cursor[1])
							{
								game->selected[0]=10;
								game->card_hold=0;
							}
							else if(game->cells[game->cursor[1]]!=52)
							{
								game->cells[game->cursor[1]]=game->cells[game->selected[1]];
								game->cells[game->selected[1]]=52;
								game->selected[0]=10;
								game->card_hold=0;
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
						else if(game->selected[0]==10 && game->cells[game->cursor[1]]!=52)
						{
							game->selected[0]=game->cursor[0];
							game->selected[1]=game->cursor[1];
						}
						else if(game->selected[0]<=7 && game->cells[game->cursor[1]]==52 && game->card_hold==1)
						{
							game->cells[game->cursor[1]]=game->columns[game->selected[0]][game->selected[1]];
							game->number[game->selected[0]]--;
							game->columns[game->selected[0]][game->selected[1]]=52;
							game->selected[0]=10;
							game->card_hold=0;
						}
						else
							no_good_move(buffer+LCD_SIZE);
					}
					else if(game->cursor[0]==9)
					{
						if(game->selected[0]==8)
						{
							if(card_test(TO_ACE, game->aces[game->cursor[1]], game->cells[game->selected[1]]))
							{
								game->aces[game->cursor[1]]=game->columns[game->selected[0]][game->selected[1]];
								game->columns[game->selected[0]][game->selected[1]]=52;
								game->selected[0]=10;
								game->card_hold=0;
								game->score+=2;
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
						else if(game->selected[0]<=7 && game->card_hold==1)
						{
							if(card_test(TO_ACE, game->aces[game->cursor[1]], game->columns[game->selected[0]][game->selected[1]]))
							{
								game->aces[game->cursor[1]]=game->columns[game->selected[0]][game->selected[1]];
								game->number[game->selected[0]]--;
								game->columns[game->selected[0]][game->selected[1]]=52;
								game->selected[0]=10;
								game->card_hold=0;
								game->score+=2;
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
					}
					else
					{
						if(game->selected[0]==8)
						{
							if(card_test(TO_CARD, game->columns[game->cursor[0]][game->cursor[1]], game->cells[game->selected[1]]))
							{
								game->columns[game->cursor[0]][game->cursor[1]+1]=game->cells[game->selected[1]];
								game->cells[game->selected[1]]=52;
								game->cursor[1]++;
								game->number[game->cursor[0]]++;
								game->selected[0]=10;
								game->card_hold=0;
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
						else if(game->selected[0]==10)
						{
							counter2=1;
							for(counter=game->cursor[1]; counter<game->number[game->cursor[0]]-1; counter++)
							{
								if(!card_test(TO_CARD, game->columns[game->cursor[0]][counter], game->columns[game->cursor[0]][counter+1]))
								{
									counter2=0;
									break;
								}
							}
							if((counter2 || game->cursor[1]==game->number[game->cursor[0]]-1) && game->number[game->cursor[0]]-game->cursor[1]-1<=game->empty && game->columns[game->cursor[0]][game->cursor[1]]!=52)
							{
								game->selected[0]=game->cursor[0];
								game->selected[1]=game->cursor[1];
								game->card_hold=game->number[game->cursor[0]]-game->cursor[1];
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
						else if(game->selected[0]<=7)
						{
							if(game->selected[0]==game->cursor[0] && game->selected[1]==game->cursor[1])
							{
								game->selected[0]=10;
								game->card_hold=0;
							}
							else if(card_test(TO_CARD, game->columns[game->cursor[0]][game->cursor[1]], game->columns[game->selected[0]][game->selected[1]]) && game->cursor[1]==game->number[game->cursor[0]]-1 && game->card_hold<=game->empty+1)
							{
								counter2=0;
								for(counter=0; counter<game->card_hold; counter++, game->cursor[1]++, game->selected[1]++)
								{
									game->columns[game->cursor[0]][game->cursor[1]+1]=game->columns[game->selected[0]][game->selected[1]];
									game->columns[game->selected[0]][game->selected[1]]=52;
								}
								game->number[game->cursor[0]]+=game->card_hold;
								game->number[game->selected[0]]-=game->card_hold;
								game->selected[0]=10;
								game->card_hold=0;
							}
							else
								no_good_move(buffer+LCD_SIZE);
						}
					}
					until_unpressed(RR_2ND);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_DIAMOND))
				{
					if(_keytest(RR_LEFT) && gray_adjust>(TI89?-28:0))
						GrayAdjust(--gray_adjust);
					else if(_keytest(RR_RIGHT) && gray_adjust<127)
						GrayAdjust(++gray_adjust);
					else if(_keytest(RR_PLUS))
						OSContrastUp();
					else if(_keytest(RR_MINUS))
						OSContrastDn();
					else
					{
						game->selected[0]=10;
						game->card_hold=0;
					}
					draw_tableau(game, buffer+LCD_SIZE);
					while(_keytest(RR_DIAMOND));
				}
				if(_keytest(RR_LEFT))
				{
					if(game->cursor[0]<=7)
					{
						game->cursor[0]+=game->cursor[0]?-1:7;
						game->cursor[1]=game->number[game->cursor[0]]-1;
					}
					else
					{
						if(game->cursor[0]==8)
						{
							if(game->cursor[1]==0)
							{
								game->cursor[0]=9;
								game->cursor[1]=3;
							}
							else
								game->cursor[1]-=1;
						}
						else if(game->cursor[0]==9)
						{
							if(game->cursor[1]==0)
							{
								game->cursor[0]=8;
								game->cursor[1]=3;
							}
							else
								game->cursor[1]-=1;
						}
					}
					delay_key(2500, RR_LEFT);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_RIGHT))
				{
					if(game->cursor[0]<=7)
					{
						game->cursor[0]=(game->cursor[0]+1)%8;
						game->cursor[1]=game->number[game->cursor[0]]-1;
					}
					else
					{
						if(game->cursor[0]==8)
						{
							if(game->cursor[1]==3)
							{
								game->cursor[0]=9;
								game->cursor[1]=0;
							}
							else
								game->cursor[1]+=1;
						}
						else if(game->cursor[0]==9)
						{
							if(game->cursor[1]==3)
							{
								game->cursor[0]=8;
								game->cursor[1]=0;
							}
							else
								game->cursor[1]+=1;
						}
					}
					delay_key(2500, RR_RIGHT);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_UP))
				{
					if(game->cursor[0]<=7)
					{
						if(game->cursor[1]>0)
							game->cursor[1]--;
						else
						{
							if(game->cursor[0]<=3)
							{
								game->cursor[1]=game->cursor[0];
								game->cursor[0]=8;
							}
							else
							{
								game->cursor[1]=game->cursor[0]-4;
								game->cursor[0]=9;
							}
						}
					}
					else
					{
						if(game->cursor[0]==8)
							game->cursor[0]=game->cursor[1];
						else if(game->cursor[0]==9)
							game->cursor[0]=game->cursor[1]+4;
						game->cursor[1]=game->number[game->cursor[0]]-1;
					}
					delay_key(2500, RR_UP);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(_keytest(RR_DOWN))
				{
					if(game->cursor[0]<=7)
					{
						if(game->cursor[1]==game->number[game->cursor[0]]-1)
						{
							if(game->cursor[0]<=3)
							{
								game->cursor[1]=game->cursor[0];
								game->cursor[0]=8;
							}
							else
							{
								game->cursor[1]=game->cursor[0]-4;
								game->cursor[0]=9;
							}
						}
						else
							game->cursor[1]++;
					}
					else
					{
						if(game->cursor[0]==8)
							game->cursor[0]=game->cursor[1];
						else if(game->cursor[0]==9)
							game->cursor[0]=game->cursor[1]+4;
						game->cursor[1]=0;
					}
					delay_key(2500, RR_DOWN);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				// Teacher Keys
				if(_keytest(RR_ESC))
				{
					menu_choice=4;
					break;
				}
				if(_keytest(RR_APPS))
					off();
				if(_keytest(RR_ENTER))
				{
					until_unpressed(RR_ENTER);
					option=0;
					GrayFastFillRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), LCD_WIDTH/2-31, LCD_HEIGHT/2-19, LCD_WIDTH/2+31, LCD_HEIGHT/2+19, COLOR_WHITE);
					GrayFastOutlineRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), LCD_WIDTH/2-32, LCD_HEIGHT/2-20, LCD_WIDTH/2+32, LCD_HEIGHT/2+20, COLOR_BLACK);
					do
					{
						GrayDrawStrExt(0, LCD_HEIGHT/2-16, "New Game", (option==0?A_REVERSE:A_REPLACE) | A_CENTERED, F_6x8);
						GrayDrawStrExt(0, LCD_HEIGHT/2-8, "Redeal", (option==1?A_REVERSE:A_REPLACE) | A_CENTERED, F_6x8);
						GrayDrawStrExt(0, LCD_HEIGHT/2, "View Stats", (option==2?A_REVERSE:A_REPLACE) | A_CENTERED, F_6x8);
						GrayDrawStrExt(0, LCD_HEIGHT/2+8, "Back", (option==3?A_REVERSE:A_REPLACE) | A_CENTERED, F_6x8);
						if(_keytest(RR_UP))
						{
							option+=option?-1:3;
							delay_key(4000, RR_UP);
						}
						if(_keytest(RR_DOWN))
						{
							option=(option+1)%4;
							delay_key(4000, RR_DOWN);
						}
						if(_keytest(RR_APPS))
							off();
						if(_keytest(RR_ESC) || _keytest(RR_CLEAR))
						{
							option=3;
							until_unpressed(RR_ESC);
							until_unpressed(RR_CLEAR);
							break;
						}
					}while(!_keytest(RR_ENTER));
					if(option==0)
					{
						shuffle(game->deck);
						game_end(LOSS, game);
					}
					if(option==1 || option==0)
						deal_cards(game);
					if(option==2)
						show_stat(game, buffer+LCD_SIZE);
					draw_tableau(game, buffer+LCD_SIZE);
				}
				if(min_aces(game->aces)==12)
				{
					game_end(WIN, game);
					game->in_progress=0;
					break;
				}
				do
				{
					counter3=0;
					for(counter=0; counter<=7; counter++)
					{
						for(counter2=0; counter2<=3; counter2++)
						{
							if(game->number[counter])
							{
								if(card_test(TO_ACE, game->aces[counter2], game->columns[counter][game->number[counter]-1]))
								{
									if(_keytest(RR_ALPHA) || min_aces(game->aces)+1>=GET_RANK(game->columns[counter][game->number[counter]-1]))
									{
										game->aces[counter2]=game->columns[counter][game->number[counter]-1];
										game->columns[counter][game->number[counter]-1]=52;
										game->number[counter]--;
										if(game->cursor[0]==counter)
											game->cursor[1]--;
										counter3=option=1;
										game->score+=2;
									}
								}
							}
						}
					}
					for(counter=0; counter<=3; counter++)
					{
						for(counter2=0; counter2<=3; counter2++)
						{
							if(card_test(TO_ACE, game->aces[counter2], game->cells[counter]))
							{
								if(_keytest(RR_ALPHA) || min_aces(game->aces)+1>=GET_RANK(game->cells[counter]))
								{
									game->aces[counter2]=game->cells[counter];
									game->cells[counter]=52;
									counter3=option=1;
									game->score+=2;
								}
							}
						}
					}
				}
				while(counter3);
				if(option)
				{
					option=0;
					game->selected[0]=10;
					draw_tableau(game, buffer+LCD_SIZE);
				}
			}while(!_keytest(RR_CLEAR));
			if(game->in_progress && menu_choice!=4)
			{
				game_end(LOSS, game);
				game->in_progress=0;
			}
			FontSetSys(F_6x8);
			GrayOff();
		}
		if(menu_choice==1)
			show_stat(game, buffer+LCD_SIZE);
		if(menu_choice==2)
		{
			// Help Screen
			DrawGrayStrExt(0, 0, "How To Play", A_REPLACE | A_CENTERED, F_8x10);
			FontSetSys(F_8x10);
			printf("\n");
			FontSetSys(F_6x8);
			printf("Arrows-Move\nClear-Quit/Clear Stats\nEnter-Options Menu\n2nd-(De)Select\nALPHA-Move to ce piles\nDiamond-Clear selected\n+/- -Inc/Dec Stagger\nEsc-Teacher Key (TI-OS)\n    Exit Game\nApps-Teacher Key (Off)");
			wait(RR_ENTER);
		}
		if(menu_choice==3)
		{
			// About Screen
			DrawGrayStrExt(0, 0, "About", A_REPLACE | A_CENTERED, F_8x10);
			FontSetSys(F_8x10);
			printf("\n");
			FontSetSys(F_6x8);
			printf("2005 by Nerdy Productions\nProgrammed by Ben Boeckel\nSpecial Thanks to:\n Jordan Krage");
			DrawGrayStrExt(0, 42, "http://nerdyproductions.sobertillnoon.com", A_REPLACE | A_CENTERED, F_4x6);
			wait(RR_ENTER);
		}
		if(menu_choice==4)
		{
			until_unpressed(RR_ENTER);
			// Reset the Interrupts
			SetIntVec(AUTO_INT_1, save_int_1);
			SetIntVec(AUTO_INT_5, save_int_5);
			static char filetype[]={0, 'N', 'r', 'd', 'P', 0, OTH_TAG};
			file=NULL;
			HANDLE data;
			MULTI_EXPR *ptr;
			HSym h;
			h=SymFind(SYMSTR("freecsav"));
			if(h.folder)
				EM_moveSymFromExtMem(SYMSTR("freecsav"), HS_NULL);
			h=SymAdd(SYMSTR("freecsav"));
			if(h.folder)
			{
				data=HeapAlloc(2+sizeof(SAVE_GAME_TEMPLATE)+sizeof(filetype));
				if(data)
				{
					ptr=HeapDeref(data);
					ptr->Size=sizeof(SAVE_GAME_TEMPLATE)+sizeof(filetype);
					memcpy(ptr->Expr, game, sizeof(SAVE_GAME_TEMPLATE));
					memcpy(ptr->Expr+sizeof(SAVE_GAME_TEMPLATE), filetype, sizeof(filetype));
					file=DerefSym(h);
					file->handle=data;
				}
				else
					SymDel(SYMSTR("freecsav"));
			}
			EM_moveSymToExtMem(SYMSTR("freecsav"), HS_NULL);
			free(game);
			memcpy(LCD_MEM, buffer, LCD_SIZE);
			free(buffer);
			ST_helpMsg("2005 Nerdy Productions");
			return;
		}
	}
}


void delay(unsigned long x)
{
	unsigned short int counter=1;
	for(; counter<=x; counter++);
	return;
}

void delay_key(unsigned long x, short int row, short int col)
{
	unsigned int counter=1;
	for(; counter<=x && _keytest(row, col); counter++);
	return;
}

void wait(short int row, short int col)
{
	while(!_keytest(row, col));
	return;
}

void until_unpressed(short int row, short int col)
{
	while(_keytest(row, col));
	return;
}

void shuffle(short int *deck)
{
	short int hold, counter=0, randomnum;
	for(; counter<=51; counter++)
	{
		randomnum=random(52);
		hold=*(deck+randomnum);
		*(deck+randomnum)=*(deck+counter);
		*(deck+counter)=hold;
	}
	return;
}

void draw_card_background(int x, int y, int selected, char *buffer)
{
	if(y>LCD_HEIGHT-25)
		y=LCD_HEIGHT-25;
	GrayFastFillRect_R(buffer, buffer+LCD_SIZE, x+1, y+1, x+14, y+23, selected?COLOR_DARKGRAY:COLOR_WHITE);
	GrayFastOutlineRect_R(buffer, buffer+LCD_SIZE, x, y, x+15, y+24, COLOR_BLACK);
	return;
}

void draw_card_value(int x, int y, short int card, char *buffer)
{
	if(y>LCD_HEIGHT-25)
		y=LCD_HEIGHT-25;
	GrayDrawStrExt2B(x+2, y+2, ranks[GET_RANK(card)], A_XOR, F_4x6, buffer, buffer+LCD_SIZE);
	GraySprite8_XOR_R(x+4, y+8, 8, suit_sprite[GET_SUIT(card)], suit_sprite[GET_SUIT(card)]+8, buffer, buffer+LCD_SIZE);
	return;
}

int card_test(short int mode, short int card_under, short int card_moving)
{
	if(mode==TO_ACE)
	{
		if((GET_RANK(card_under)==GET_RANK(card_moving)-1 && GET_SUIT(card_under)==GET_SUIT(card_moving)) || (card_under==52 && GET_RANK(card_moving)==0 && card_moving!=52))
			return 1;
		else
			return 0;
	}
	else
	{
		if((GET_RANK(card_under)-1==GET_RANK(card_moving) && GET_COLOR(card_under)!=GET_COLOR(card_moving)) || card_under==52)
			return 1;
		else
			return 0;
	}
}

void show_selected_card(short int card, char *buffer)
{
	GrayDrawStrExt2B(0, 1, ranks[GET_RANK(card)], A_CENTERED | A_REPLACE, F_6x8, buffer, buffer+LCD_SIZE);
	GraySprite8_OR_R(LCD_WIDTH/2-4, 9, 8, suit_sprite[GET_SUIT(card)], suit_sprite[GET_SUIT(card)]+8, buffer, buffer+LCD_SIZE);
	return;
}

void deal_cards(SAVE_GAME_TEMPLATE *game)
{
	int counter=0, counter2;
	for(; counter<=7; counter++)
	{
		if(counter<=3)
		{
			game->number[counter]=7;
			game->aces[counter]=game->cells[counter]=52;
		}
		else
			game->number[counter]=6;
		for(counter2=0; counter2<=19; counter2++)
			game->columns[counter][counter2]=52;
	}
	for(counter=0; counter<=51; counter++)
		game->columns[counter%8][counter/8]=game->deck[counter];
	game->selected[0]=10;
	game->cursor[0]=0;
	game->cursor[1]=6;
	game->in_progress=1;
	game->score-=35;
	return;
}

void draw_tableau(SAVE_GAME_TEMPLATE *game, char *buffer)
{
	int counter=0, counter2;
	GrayClearScreen2B_R(buffer, buffer+LCD_SIZE);
	for(; counter<=7; counter++)
	{
		for(counter2=0; counter2<=18; counter2++)
		{
			if(counter2==0 || game->columns[counter][counter2]!=52)
				draw_card_background(LCD_WIDTH/8*counter, game->stagger*counter2+26, ((game->selected[0]==counter && game->selected[1]==counter2) || (game->cursor[0]==counter && game->cursor[1]==counter2) || (counter2==0 && game->cursor[0]==counter && game->number[game->cursor[0]]==0))?1:0, buffer);
			if(game->columns[counter][counter2]!=52)
			{
				if(game->cursor[0]==counter && game->cursor[1]==counter2)
					show_selected_card(game->columns[counter][counter2], buffer);
				draw_card_value(LCD_WIDTH/8*counter, game->stagger*counter2+26, game->columns[counter][counter2], buffer);
			}
		}
	}
	for(counter=0; counter<=3; counter++)
	{
		if(game->cursor[0]==8 && game->cursor[1]==counter && game->cells[game->cursor[1]]!=52)
			show_selected_card(game->cells[counter], buffer);
		draw_card_background((TI89?18:30)*counter, 0, ((game->selected[0]==8 && game->selected[1]==counter) || (game->cursor[0]==8 && game->cursor[1]==counter))?1:0, buffer);
		if(game->cells[counter]!=52)
			draw_card_value((TI89?18:30)*counter, 0, game->cells[counter], buffer);
	}
	for(counter=0; counter<=3; counter++)
	{
		if(game->cursor[0]==9 && game->cursor[1]==counter && game->aces[game->cursor[1]]!=52)
			show_selected_card(game->aces[counter], buffer);
		draw_card_background(LCD_WIDTH-16-(TI89?18:30)*(3-counter), 0, ((game->selected[0]==9 && game->selected[1]==counter) || (game->cursor[0]==9 && game->cursor[1]==counter))?1:0, buffer);
		if(game->aces[counter]!=52)
			draw_card_value(LCD_WIDTH-16-(TI89?18:30)*(3-counter), 0, game->aces[counter], buffer);
	}
	FastCopyScreen_R(buffer, GrayGetPlane(LIGHT_PLANE));
	FastCopyScreen_R(buffer+LCD_SIZE, GrayGetPlane(DARK_PLANE));
	return;
}

int min_aces(short int *aces)
{
	int counter=0, little=13;
	for(; counter<=3; counter++)
		little=min(little, GET_RANK(*(aces+counter)));
	return little;
}

void game_end(short int end_type, SAVE_GAME_TEMPLATE *game)
{
	int x_vel=2, y_vel=random(6)+1, x=0, y=0, card, counter=0;
	if(end_type==WIN)
	{
		game->win++;
		if(game->last_result==WIN)
			game->streak_current++;
		else
		{
			game->last_result=WIN;
			game->streak_current=1;
		}
		if(game->streak_current>game->streak_win)
			game->streak_win=game->streak_current;
		do
		{
			card=random(52);
			GrayFastFillRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), x+1, y+1, x+14, y+23, COLOR_WHITE);
			GrayFastOutlineRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), x, y, x+15, y+24, COLOR_BLACK);
			GrayDrawStrExt2B(x+2, y+2, ranks[GET_RANK(card)], A_NORMAL, F_4x6, GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE));
			GraySprite8_XOR_R(x+4, y+8, 8, suit_sprite[GET_SUIT(card)], suit_sprite[GET_SUIT(card)]+8, GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE));
			GrayFastFillRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), LCD_WIDTH/2-32, LCD_HEIGHT/2-5, LCD_WIDTH/2+30, LCD_HEIGHT/2+5, COLOR_WHITE);
			GrayFastOutlineRect_R(GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE), LCD_WIDTH/2-33, LCD_HEIGHT/2-6, LCD_WIDTH/2+31, LCD_HEIGHT/2+6, COLOR_BLACK);
			GrayDrawStrExt2B(0, LCD_HEIGHT/2-4, "YOU WIN!", A_CENTERED | A_NORMAL, F_8x10, GrayGetPlane(LIGHT_PLANE), GrayGetPlane(DARK_PLANE));
			x+=x_vel;
			y+=y_vel;
			y_vel+=2;
			if(x>=LCD_WIDTH-16)
				x_vel=-2;
			if(x==0)
				x_vel=2;
			if(y>=LCD_HEIGHT-27-y_vel)
				y_vel=-random(10)-6;
			if(y<y_vel+2)
				y_vel=random(10)+6;
			delay(15000);
			counter++;
		}while(!_keytest(RR_ENTER) && counter<=500);
		until_unpressed(RR_ENTER);
	}
	else
	{
		game->loss++;
		if(game->last_result==LOSS)
			game->streak_current++;
		else
		{
			game->last_result=LOSS;
			game->streak_current=1;
		}
		if(game->streak_current>game->streak_loss)
			game->streak_loss=game->streak_current;
	}
	return;
}

void determine_empty(SAVE_GAME_TEMPLATE *game)
{
	int counter=0;
	game->empty=0;
	for(; counter<=7; counter++)
	{
		if(game->number[counter]==0 && game->cursor[0]!=counter)
			game->empty++;
	}
	for(counter=0; counter<=3; counter++)
	{
		if(game->cells[counter]==52)
			game->empty++;
	}
	return;
}

void show_stat(SAVE_GAME_TEMPLATE *game, char *buffer)
{
	GrayClearScreen_R();
	DrawGrayStrExt(0, 0, "Stats", A_NORMAL | A_CENTERED, F_8x10);
	DrawGrayStrExt(0, 10, "Wins.................", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 18, "Losses...............", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 26, "Win Percentage.......", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 34, "Best Winning Streak..", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 42, "Worst Losing Streak..", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 50, "Current Streak.......", A_NORMAL, F_6x8);
	DrawGrayStrExt(0, 58, "Best Score...........", A_NORMAL, F_6x8);
	FastCopyScreen_R(GrayGetPlane(LIGHT_PLANE), buffer+LCD_SIZE);
	do
	{
		sprintf(buffer, "%lu", game->win);
		DrawGrayStrExt(126, 10, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%lu", game->loss);
		DrawGrayStrExt(126, 18, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%lu%%", game->last_result==NO_GAME?0:100*game->win/(game->win+game->loss));
		DrawGrayStrExt(126, 26, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%lu", game->streak_win);
		DrawGrayStrExt(126, 34, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%lu", game->streak_loss);
		DrawGrayStrExt(126, 42, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%lu", game->streak_current);
		DrawGrayStrExt(126, 50, buffer, A_NORMAL, F_6x8);
		sprintf(buffer, "%ld", game->best_score);
		DrawGrayStrExt(126, 58, buffer, A_NORMAL, F_6x8);
		if(_keytest(RR_CLEAR))
		{
			game->win=game->loss=game->streak_win=game->streak_loss=game->streak_current=game->score=0;
			game->best_score=-35;
			game->last_result=NO_GAME;
			shuffle(game->deck);
			deal_cards(game);
			FastCopyScreen_R(buffer+LCD_SIZE, GrayGetPlane(LIGHT_PLANE));
			FastCopyScreen_R(buffer+LCD_SIZE, GrayGetPlane(DARK_PLANE));
		}
	}while(!_keytest(RR_ENTER));
	until_unpressed(RR_ENTER);
	return;
}

void no_good_move(char *buffer)
{
	GrayFastFillRect_R(buffer, buffer+LCD_SIZE, LCD_WIDTH/2-61, LCD_HEIGHT/2-4, LCD_WIDTH/2+61, LCD_HEIGHT/2+4, COLOR_WHITE);
	GrayFastOutlineRect_R(buffer, buffer+LCD_SIZE, LCD_WIDTH/2-62, LCD_HEIGHT/2-5, LCD_WIDTH/2+62, LCD_HEIGHT/2+5, COLOR_BLACK);
	GrayDrawStrExt2B(LCD_WIDTH/2-60, LCD_HEIGHT/2-3, "That is not allowed!", A_NORMAL, F_6x8, buffer, buffer+LCD_SIZE);
	FastCopyScreen_R(buffer, GrayGetPlane(LIGHT_PLANE));
	FastCopyScreen_R(buffer+LCD_SIZE, GrayGetPlane(DARK_PLANE));
	delay(5000);
	return;
}